@@ -478,7 +478,7 @@ This formule is derived from Graphic Gems pag. 600
 
     e = pixel size
     h = step
-    a = acceleration of curve (for a quadratic is a costant value)
+    a = acceleration of curve (for a quadratic is a constant value)
 */
 
 double computeStep(const TQuadratic &quad, double pixelSize) {
