@@ -196,6 +196,8 @@ class FxSchematicPort final : public SchematicPort {
   QList<SchematicLink *> m_hiddenLinks;
   QList<SchematicLink *> m_ghostLinks;
 
+  bool m_isPassThrough;
+
 public:
   FxSchematicPort(FxSchematicDock *parent, int type);
   ~FxSchematicPort();
@@ -207,6 +209,8 @@ public:
   FxSchematicDock *getDock() const;
   SchematicLink *makeLink(SchematicPort *port) override;
 
+  void setIsPassThrough();
+
 protected:
   void contextMenuEvent(QGraphicsSceneContextMenuEvent *cme) override;
   void mouseMoveEvent(QGraphicsSceneMouseEvent *me) override;
@@ -596,4 +600,62 @@ protected slots:
   void onRenderToggleClicked(bool);
 };
 
+//*****************************************************
+//    FxPassThroughPainter
+//*****************************************************
+class FxSchematicPassThroughNode;
+class FxPassThroughPainter final : public QObject, public QGraphicsItem {
+  Q_OBJECT
+  Q_INTERFACES(QGraphicsItem)
+
+  double m_width, m_height;
+  QString m_name;
+  bool m_showName;
+
+  FxSchematicPassThroughNode *m_parent;
+
+public:
+  FxPassThroughPainter(FxSchematicPassThroughNode *parent, double width,
+                       double height, const QString &name, bool showName);
+  ~FxPassThroughPainter();
+
+  QRectF boundingRect() const override;
+  void paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
+             QWidget *widget = 0) override;
+  void setName(const QString &name) { m_name = name; }
+  void setShowName(bool showName) { m_showName = showName; }
+
+protected:
+  void contextMenuEvent(QGraphicsSceneContextMenuEvent *cme) override;
+};
+
+//*****************************************************
+//    FxSchematicPassThroughNode
+//*****************************************************
+
+class FxSchematicPassThroughNode final : public FxSchematicNode {
+  Q_OBJECT
+
+  bool m_showName;
+
+  FxPassThroughPainter *m_passThroughPainter;
+
+public:
+  FxSchematicPassThroughNode(FxSchematicScene *scene, TFx *fx);
+  ~FxSchematicPassThroughNode();
+
+  QRectF boundingRect() const override;
+  void paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
+             QWidget *widget = 0) override;
+  bool isOpened() override { return false; }
+
+protected:
+  void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *me) override;
+  void mousePressEvent(QGraphicsSceneMouseEvent *me) override;
+
+protected slots:
+
+  void onNameChanged();
+};
+
 #endif  // FXSCHEMATICNODE_H
