@@ -90,7 +90,7 @@ protected:
   //! Returns \b true if no nodes intersects \b rect.
   bool isAnEmptyZone(const QRectF &rect);
   //! Returns a vector containing all nodes which had their bounding rects
-  //! conatined in \b node bounding
+  //! contained in \b node bounding
   //! rect enlarged of 10.
   QVector<SchematicNode *> getPlacedNode(SchematicNode *node);
 
@@ -294,6 +294,11 @@ class DVAPI SchematicViewer final : public QWidget {
   QColor m_xsheetColor;
   Q_PROPERTY(QColor XsheetColor READ getXsheetColor WRITE setXsheetColor)
 
+  // Pass Through node
+  QColor m_passThroughColor;
+  Q_PROPERTY(QColor PassThroughColor READ getPassThroughColor WRITE
+                 setPassThroughColor)
+
   // Fx nodes
   QColor m_normalFx;
   Q_PROPERTY(QColor NormalFxColor READ getNormalFxColor WRITE setNormalFxColor)
@@ -472,6 +477,10 @@ public:
   void setXsheetColor(const QColor &color) { m_xsheetColor = color; }
   QColor getXsheetColor() const { return m_xsheetColor; }
 
+  // Pass Through node
+  void setPassThroughColor(const QColor &color) { m_passThroughColor = color; }
+  QColor getPassThroughColor() const { return m_passThroughColor; }
+
   // Fx nodes
   QColor getNormalFxColor() const { return m_normalFx; }
   void setNormalFxColor(const QColor &color) { m_normalFx = color; }
