@@ -22,6 +22,7 @@
 #include "toonzqt/colorfield.h"
 #include "toonzqt/tabbar.h"
 #include "toonzqt/glwidget_for_highdpi.h"
+#include "toonzqt/hexcolornames.h"
 
 // Qt includes
 #include <QWidget>
@@ -238,14 +239,15 @@ signals:
 //=============================================================================
 /*! \brief The ColorSlider is used to set a color channel.
 
-                Inherits \b QSlider.
+                Inherits \b QAbstractSlider.
 
                 This object show a bar which colors differ from minimum to
    maximum channel color
                 value.
 */
-class DVAPI ColorSlider final : public QSlider {
+class DVAPI ColorSlider final : public QAbstractSlider {
   Q_OBJECT
+
 public:
   ColorSlider(Qt::Orientation orientation, QWidget *parent = 0);
 
@@ -259,6 +261,9 @@ protected:
   void paintEvent(QPaintEvent *event) override;
   void mousePressEvent(QMouseEvent *event) override;
   void mouseReleaseEvent(QMouseEvent *event) override;
+  void mouseMoveEvent(QMouseEvent *event) override;
+
+  void chandleMouse(int x, int y);
 
   //	QIcon getFirstArrowIcon();
   //	QIcon getLastArrowIcon();
@@ -268,6 +273,11 @@ protected:
 private:
   ColorChannel m_channel;
   ColorModel m_color;
+  static int s_chandle_size;
+  static int s_chandle_tall;
+
+public:
+  static int s_slider_appearance;
 };
 
 //=============================================================================
@@ -614,6 +624,8 @@ class DVAPI StyleEditor final : public QWidget, public SaveLoadQSettings {
   PaletteController *m_paletteController;
   TPaletteHandle *m_paletteHandle;
   TPaletteHandle *m_cleanupPaletteHandle;
+  DVGui::HexLineEdit *m_hexLineEdit;
+  DVGui::HexColorNamesEditor *m_hexColorNamesEditor;
   QWidget *m_parent;
   TXshLevelHandle
       *m_levelHandle;  //!< for clearing the level cache when the color changed
@@ -652,6 +664,9 @@ class DVAPI StyleEditor final : public QWidget, public SaveLoadQSettings {
   QAction *m_hsvAction;
   QAction *m_alphaAction;
   QAction *m_rgbAction;
+  QAction *m_hexAction;
+  QActionGroup *m_sliderAppearanceAG;
+  QAction *m_hexEditorAction;
 
   TColorStyleP
       m_oldStyle;  //!< A copy of current style \a before the last change.
@@ -727,7 +742,8 @@ protected slots:
   void onStyleSwitched();
   void onStyleChanged(bool isDragging);
   void onCleanupStyleChanged(bool isDragging);
-  void onOldStyleClicked(const TColorStyle &);
+  void onOldStyleClicked();
+  void onNewStyleClicked();
   void updateOrientationButton();
   void checkPaletteLock();
   // called (e.g.) by PaletteController when an other StyleEditor change the
@@ -752,10 +768,16 @@ protected slots:
 
   void onParamStyleChanged(bool isDragging);
 
+  void onHexChanged();
+  void onHexEditor();
+
   void onSpecialButtonToggled(bool on);
   void onCustomButtonToggled(bool on);
   void onVectorBrushButtonToggled(bool on);
 
+  void onSliderAppearanceSelected(QAction *);
+  void onPopupMenuAboutToShow();
+
 private:
   QFrame *createBottomWidget();
   QFrame *createVectorPage();
