@@ -183,7 +183,7 @@ inline std::string traduce(const TAffine &aff) {
       (areAlmostEqual(aff.a23, 0.0) ? "0" : ::to_string(aff.a23, 5));
 }
 
-}  // Local namespace
+}  // namespace
 
 //------------------------------------------------------------------------------
 
@@ -541,8 +541,11 @@ TAffine TRasterFx::handledAffine(const TRenderSettings &info, double frame) {
 bool TRasterFx::getBBox(double frame, TRectD &bBox,
                         const TRenderSettings &info) {
   bool ret = doGetBBox(frame, bBox, info);
-  bBox     = info.m_affine * bBox;
-  enlargeToI(bBox);
+  if (!bBox.isEmpty()) {  // TODO: check if bbox can always be empty when ret ==
+                          // false
+    bBox = info.m_affine * bBox;
+    enlargeToI(bBox);
+  }
   return ret;
 }
 
@@ -1073,7 +1076,8 @@ TRenderSettings::TRenderSettings()
     , m_isSwatch(false)
     , m_applyShrinkToViewer(false)
     , m_userCachable(true)
-    , m_isCanceled(NULL) {}
+    , m_isCanceled(NULL)
+    , m_getFullSizeBBox(false) {}
 
 //------------------------------------------------------------------------------
 
