@@ -17,6 +17,7 @@
 #include "tparamuiconcept.h"
 
 #include "historytypes.h"
+#include "toonzqt/gutil.h"
 
 #include <QApplication>
 #include <QDesktopWidget>
@@ -26,11 +27,6 @@ using namespace EditToolGadgets;
 GLdouble FxGadget::m_selectedColor[3] = {0.2, 0.8, 0.1};
 
 namespace {
-int getDevPixRatio() {
-  static int devPixRatio = QApplication::desktop()->devicePixelRatio();
-  return devPixRatio;
-}
-
 TPointD hadamard(const TPointD &v1, const TPointD &v2) {
   return TPointD(v1.x * v2.x, v1.y * v2.y);
 }
@@ -134,12 +130,11 @@ public:
   }
 
   void leftButtonUp(const TPointD &pos, const TMouseEvent &e) override {
-    // precise control with pressing Alt key
-    if (e.isAltPressed()) {
-      TPointD precisePos = m_firstPos + (pos - m_firstPos) * 0.1;
-      m_gadget->leftButtonUp(getMatrix() * precisePos, e);
-    } else
-      m_gadget->leftButtonUp(getMatrix() * pos, e);
+    leftButtonUp();
+  }
+
+  void leftButtonUp() override {
+    m_gadget->leftButtonUp();
     m_gadget->commitUndo();
   }
 };
@@ -200,14 +195,14 @@ void FxGadget::setValue(const TPointParamP &param, const TPointD &pos) {
 //---------------------------------------------------------------------------
 
 void FxGadget::setPixelSize() {
-  setPixelSize(sqrt(tglGetPixelSize2()) * getDevPixRatio());
+  setPixelSize(sqrt(tglGetPixelSize2()) * m_controller->getDevPixRatio());
 }
 
 //---------------------------------------------------------------------------
 
 void FxGadget::drawTooltip(const TPointD &tooltipPos,
                            std::string tooltipPosText) {
-  double unit = sqrt(tglGetPixelSize2()) * getDevPixRatio();
+  double unit = sqrt(tglGetPixelSize2()) * m_controller->getDevPixRatio();
   glPushMatrix();
   glTranslated(tooltipPos.x, tooltipPos.y, 0.0);
   double sc = unit * 1.6;
@@ -274,7 +269,6 @@ public:
 
   void leftButtonDown(const TPointD &pos, const TMouseEvent &) override;
   void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override;
 };
 
 //---------------------------------------------------------------------------
@@ -322,10 +316,6 @@ void PointFxGadget::leftButtonDrag(const TPointD &pos, const TMouseEvent &) {
   if (m_yParam) setValue(m_yParam, pos.y);
 }
 
-//---------------------------------------------------------------------------
-
-void PointFxGadget::leftButtonUp(const TPointD &pos, const TMouseEvent &) {}
-
 //=============================================================================
 
 class RadiusFxGadget final : public FxGadget {
@@ -345,7 +335,6 @@ public:
 
   void leftButtonDown(const TPointD &pos, const TMouseEvent &) override;
   void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override;
 };
 
 //---------------------------------------------------------------------------
@@ -390,10 +379,6 @@ void RadiusFxGadget::leftButtonDrag(const TPointD &pos, const TMouseEvent &) {
   setValue(m_radius, norm(pos - getCenter()));
 }
 
-//---------------------------------------------------------------------------
-
-void RadiusFxGadget::leftButtonUp(const TPointD &pos, const TMouseEvent &) {}
-
 //=============================================================================
 
 class DistanceFxGadget final : public FxGadget {
@@ -422,7 +407,6 @@ public:
 
   void leftButtonDown(const TPointD &pos, const TMouseEvent &) override;
   void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override;
 };
 
 //---------------------------------------------------------------------------
@@ -474,10 +458,6 @@ void DistanceFxGadget::leftButtonDrag(const TPointD &pos, const TMouseEvent &) {
   setValue(m_distance, v);
 }
 
-//---------------------------------------------------------------------------
-
-void DistanceFxGadget::leftButtonUp(const TPointD &pos, const TMouseEvent &) {}
-
 //=============================================================================
 
 class AngleFxGadget final : public FxGadget {
@@ -492,7 +472,6 @@ public:
 
   void leftButtonDown(const TPointD &pos, const TMouseEvent &) override;
   void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override;
 };
 
 //---------------------------------------------------------------------------
@@ -511,7 +490,7 @@ void AngleFxGadget::draw(bool picking) {
   else
     glColor3d(0, 0, 1);
   glPushName(getId());
-  double pixelSize = sqrt(tglGetPixelSize2()) * getDevPixRatio();
+  double pixelSize = sqrt(tglGetPixelSize2()) * m_controller->getDevPixRatio();
   double r         = pixelSize * 40;
   double a = pixelSize * 10, b = pixelSize * 5;
   tglDrawCircle(m_pos, r);
@@ -547,10 +526,6 @@ void AngleFxGadget::leftButtonDrag(const TPointD &pos, const TMouseEvent &) {
   setValue(m_param, phi * M_180_PI);
 }
 
-//---------------------------------------------------------------------------
-
-void AngleFxGadget::leftButtonUp(const TPointD &pos, const TMouseEvent &) {}
-
 //=============================================================================
 
 class AngleRangeFxGadget final : public FxGadget {
@@ -571,7 +546,7 @@ public:
 
   void leftButtonDown(const TPointD &pos, const TMouseEvent &) override;
   void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override;
+  void leftButtonUp() override;
 };
 
 //---------------------------------------------------------------------------
@@ -600,7 +575,7 @@ void AngleRangeFxGadget::draw(bool picking) {
       glColor3d(0, 0, 1);
   };
 
-  double pixelSize = sqrt(tglGetPixelSize2()) * getDevPixRatio();
+  double pixelSize = sqrt(tglGetPixelSize2()) * m_controller->getDevPixRatio();
   double r         = pixelSize * 200;
   double a         = pixelSize * 30;
 
@@ -712,9 +687,7 @@ void AngleRangeFxGadget::leftButtonDrag(const TPointD &pos,
 
 //---------------------------------------------------------------------------
 
-void AngleRangeFxGadget::leftButtonUp(const TPointD &pos, const TMouseEvent &) {
-  m_handle = None;
-}
+void AngleRangeFxGadget::leftButtonUp() { m_handle = None; }
 
 //=============================================================================
 
@@ -731,7 +704,6 @@ public:
 
   void leftButtonDown(const TPointD &pos, const TMouseEvent &) override {}
   void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override {}
 };
 
 //---------------------------------------------------------------------------
@@ -797,7 +769,6 @@ public:
 
   void leftButtonDown(const TPointD &pos, const TMouseEvent &) override {}
   void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override {}
 };
 
 //---------------------------------------------------------------------------
@@ -876,7 +847,6 @@ public:
 
   void leftButtonDown(const TPointD &pos, const TMouseEvent &) override;
   void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override {}
 };
 
 //---------------------------------------------------------------------------
@@ -1017,7 +987,6 @@ public:
     setValue(m_phiParam, phi * M_180_PI);
     setValue(m_lengthParam, length);
   }
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override {}
 };
 
 //=============================================================================
@@ -1073,7 +1042,6 @@ public:
 
   void leftButtonDown(const TPointD &pos, const TMouseEvent &) override {}
   void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override {}
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override {}
 };
 
 //=============================================================================
@@ -1196,7 +1164,7 @@ public:
 
   void leftButtonDown(const TPointD &pos, const TMouseEvent &) override;
   void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override;
+  void leftButtonUp() override;
 };
 
 //---------------------------------------------------------------------------
@@ -1338,9 +1306,7 @@ void QuadFxGadget::leftButtonDrag(const TPointD &pos, const TMouseEvent &e) {
 
 //---------------------------------------------------------------------------
 
-void QuadFxGadget::leftButtonUp(const TPointD &pos, const TMouseEvent &) {
-  m_handle = None;
-}
+void QuadFxGadget::leftButtonUp() { m_handle = None; }
 
 //=============================================================================
 
@@ -1361,7 +1327,7 @@ public:
 
   void leftButtonDown(const TPointD &pos, const TMouseEvent &) override;
   void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
-  void leftButtonUp(const TPointD &pos, const TMouseEvent &) override;
+  void leftButtonUp() override;
 };
 
 //---------------------------------------------------------------------------
@@ -1525,10 +1491,279 @@ void LinearRangeFxGadget::leftButtonDrag(const TPointD &pos,
 
 //---------------------------------------------------------------------------
 
-void LinearRangeFxGadget::leftButtonUp(const TPointD &pos,
-                                       const TMouseEvent &) {
-  m_handle = None;
+void LinearRangeFxGadget::leftButtonUp() { m_handle = None; }
+
+//=============================================================================
+
+class CompassFxGadget final : public FxGadget {
+  TPointParamP m_center;
+
+  enum HANDLE { Body = 0, Near, Far, None } m_handle = None;
+
+  TPointD m_clickedPos, m_mousePos;
+  TPointD m_targetPos, m_anotherPos;
+
+  bool m_isSpin;
+
+public:
+  CompassFxGadget(FxGadgetController *controller,
+                  const TPointParamP &centerPoint, bool isSpin = false);
+
+  void draw(bool picking) override;
+
+  void leftButtonDown(const TPointD &pos, const TMouseEvent &) override;
+  void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
+  void leftButtonUp() override;
+};
+
+//---------------------------------------------------------------------------
+
+CompassFxGadget::CompassFxGadget(FxGadgetController *controller,
+                                 const TPointParamP &centerPoint, bool isSpin)
+    : FxGadget(controller, 3), m_center(centerPoint), m_isSpin(isSpin) {
+  addParam(centerPoint->getX());
+  addParam(centerPoint->getY());
 }
+
+//---------------------------------------------------------------------------
+
+void CompassFxGadget::draw(bool picking) {
+  auto setColorById = [&](int id) {
+    if (isSelected(id))
+      glColor3dv(m_selectedColor);
+    else
+      glColor3d(0, 0, 1);
+  };
+
+  auto drawArrow = [&]() {
+    double arrowLength = getPixelSize() * 20;
+    double arrowTip    = getPixelSize() * 5;
+
+    glBegin(GL_LINES);
+    glVertex2d(-arrowLength, 0.0);
+    glVertex2d(arrowLength, 0.0);
+
+    glVertex2d(-arrowLength + arrowTip, arrowTip);
+    glVertex2d(-arrowLength, 0.0);
+
+    glVertex2d(-arrowLength + arrowTip, -arrowTip);
+    glVertex2d(-arrowLength, 0.0);
+
+    glVertex2d(arrowLength - arrowTip, arrowTip);
+    glVertex2d(arrowLength, 0.0);
+
+    glVertex2d(arrowLength - arrowTip, -arrowTip);
+    glVertex2d(arrowLength, 0.0);
+    glEnd();
+  };
+
+  setPixelSize();
+  double lineHalf     = getPixelSize() * 100;
+  double lineInterval = getPixelSize() * 50;
+  double r            = getPixelSize() * 3;
+
+  glPushMatrix();
+
+  TPointD center = getValue(m_center);
+  double dCenter = norm(center);
+  TPointD handleVec;
+  if (dCenter > lineHalf) {
+    handleVec = normalize(center) * lineHalf;
+    setColorById(Body);
+    glPushName(getId() + Body);
+    glBegin(GL_LINES);
+    glVertex2d(handleVec.x * 0.95, handleVec.y * 0.95);
+    glVertex2d(-handleVec.x * 0.95, -handleVec.y * 0.95);
+    glEnd();
+    glPopName();
+
+    double angle = std::atan2(-center.y, -center.x) * M_180_PI;
+    double theta = M_180_PI * lineInterval / dCenter;
+
+    // draw guides
+    glColor3d(0, 0, 1);
+    glLineStipple(1, 0x00FF);
+    glEnable(GL_LINE_STIPPLE);
+    glPushMatrix();
+    glTranslated(center.x, center.y, 0);
+    glRotated(angle, 0, 0, 1);
+    for (int i = -3; i <= 3; i++) {
+      if (!m_isSpin) {  // radial direction
+        if (i == 0) continue;
+        glPushMatrix();
+        glRotated(theta * (double)i, 0, 0, 1);
+        glBegin(GL_LINES);
+        glVertex2d(dCenter - lineHalf, 0.0);
+        glVertex2d(dCenter + lineHalf, 0.0);
+        glEnd();
+        glPopMatrix();
+      } else {  // rotational direction
+        if (i == 3 || i == -3) continue;
+        double tmpRad  = dCenter + (double)i * lineInterval;
+        double d_angle = (lineInterval / dCenter) * 6.0 / 10.0;
+        glBegin(GL_LINE_STRIP);
+        for (int r = -5; r <= 5; r++) {
+          double tmpAngle = (double)r * d_angle;
+          glVertex2d(tmpRad * std::cos(tmpAngle), tmpRad * std::sin(tmpAngle));
+        }
+        glEnd();
+      }
+    }
+
+    glPopMatrix();
+    glDisable(GL_LINE_STIPPLE);
+
+    for (int id = Near; id <= Far; id++) {
+      TPointD hPos = (id == Near) ? handleVec : -handleVec;
+      setColorById(id);
+      glPushName(getId() + id);
+      glPushMatrix();
+      glTranslated(hPos.x, hPos.y, 0);
+      tglDrawRect(-r, -r, r, r);
+      glPopMatrix();
+      glPopName();
+    }
+  }
+
+  if (m_handle == Body) {
+    glPushMatrix();
+    TPointD centerOffset = center - m_targetPos;
+    handleVec            = normalize(m_targetPos) * lineHalf;
+    glTranslated(centerOffset.x, centerOffset.y, 0);
+    glBegin(GL_LINES);
+    glVertex2d(handleVec.x, handleVec.y);
+    glVertex2d(-handleVec.x, -handleVec.y);
+    glEnd();
+    glPopMatrix();
+  }
+  glPopMatrix();
+}
+
+//---------------------------------------------------------------------------
+
+void CompassFxGadget::leftButtonDown(const TPointD &pos, const TMouseEvent &) {
+  m_handle = (HANDLE)m_selected;
+  if (m_handle == None) return;
+  m_clickedPos = pos;
+  m_targetPos  = getValue(m_center);
+}
+
+//---------------------------------------------------------------------------
+
+void CompassFxGadget::leftButtonDrag(const TPointD &pos, const TMouseEvent &e) {
+  if (m_handle == None) return;
+  TPointD d = pos - m_clickedPos;
+
+  if (m_handle == Body) {
+    setValue(m_center, m_targetPos + d);
+    return;
+  }
+
+  double angle =
+      std::atan2(pos.y, pos.x) - std::atan2(m_clickedPos.y, m_clickedPos.x);
+  double scale = norm(pos) / norm(m_clickedPos);
+
+  QTransform transform;
+  QPointF p = transform.rotateRadians(angle)
+                  .scale(scale, scale)
+                  .map(QPointF(m_targetPos.x, m_targetPos.y));
+
+  setValue(m_center, TPointD(p.x(), p.y()));
+}
+
+//---------------------------------------------------------------------------
+
+void CompassFxGadget::leftButtonUp() { m_handle = None; }
+
+//=============================================================================
+
+class RainbowWidthFxGadget final : public FxGadget {
+  TDoubleParamP m_widthScale;
+  TDoubleParamP m_radius;
+  TPointParamP m_center;
+
+  enum HANDLE { Outside = 0, Inside, None } m_handle = None;
+
+public:
+  RainbowWidthFxGadget(FxGadgetController *controller,
+                       const TDoubleParamP &widthScale,
+                       const TDoubleParamP &radius, const TPointParamP &center)
+      : FxGadget(controller, 2)
+      , m_widthScale(widthScale)
+      , m_radius(radius)
+      , m_center(center) {
+    addParam(widthScale);
+  }
+
+  void draw(bool picking) override;
+
+  void leftButtonDown(const TPointD &pos, const TMouseEvent &) override;
+  void leftButtonDrag(const TPointD &pos, const TMouseEvent &) override;
+};
+
+//---------------------------------------------------------------------------
+
+void RainbowWidthFxGadget::draw(bool picking) {
+  setPixelSize();
+  if (isSelected())
+    glColor3dv(m_selectedColor);
+  else
+    glColor3d(0, 0, 1);
+  double radius     = getValue(m_radius);
+  TPointD center    = getValue(m_center);
+  double widthScale = getValue(m_widthScale);
+  double w          = widthScale * radius / 41.3;
+
+  glPushName(getId() + Outside);
+  glLineStipple(1, 0x1C47);
+  glEnable(GL_LINE_STIPPLE);
+  tglDrawCircle(center, radius + w);
+  glDisable(GL_LINE_STIPPLE);
+  drawDot(center + TPointD(0.707, 0.707) * (radius + w));
+  glPopName();
+
+  if (isSelected(Outside)) {
+    drawTooltip(center + TPointD(0.707, 0.707) * (radius + w), getLabel());
+  }
+
+  glPushName(getId() + Inside);
+  glLineStipple(1, 0x1C47);
+  glEnable(GL_LINE_STIPPLE);
+  tglDrawCircle(center, radius - w);
+  glDisable(GL_LINE_STIPPLE);
+  drawDot(center + TPointD(0.707, 0.707) * (radius - w));
+  glPopName();
+
+  if (isSelected(Inside)) {
+    drawTooltip(center + TPointD(0.707, 0.707) * (radius - w), getLabel());
+  }
+}
+
+//---------------------------------------------------------------------------
+
+void RainbowWidthFxGadget::leftButtonDown(const TPointD &pos,
+                                          const TMouseEvent &) {
+  m_handle = (HANDLE)m_selected;
+}
+
+//---------------------------------------------------------------------------
+
+void RainbowWidthFxGadget::leftButtonDrag(const TPointD &pos,
+                                          const TMouseEvent &) {
+  if (m_handle == None) return;
+
+  double radius = getValue(m_radius);
+  double wpos   = norm(pos - getValue(m_center));
+  double width  = (m_handle == Outside) ? wpos - radius : radius - wpos;
+
+  double scale = (width * 41.3) / (radius * 1.0);
+
+  double min, max, step;
+  m_widthScale->getValueRange(min, max, step);
+
+  setValue(m_widthScale, std::min(max, std::max(min, scale)));
+}
+
 //*************************************************************************************
 //    FxGadgetController  implementation
 //*************************************************************************************
@@ -1592,15 +1827,16 @@ void FxGadgetController::draw(bool picking) {
 //---------------------------------------------------------------------------
 
 void FxGadgetController::selectById(unsigned int id) {
-  std::map<GLuint, FxGadget *>::iterator it;
-  it                       = m_idTable.find(id);
-  FxGadget *selectedGadget = it != m_idTable.end() ? it->second : 0;
+  std::map<GLuint, FxGadget *>::iterator it = m_idTable.find(id);
+  FxGadget *selectedGadget = it != m_idTable.end() ? it->second : nullptr;
   if (selectedGadget != m_selectedGadget) {
     if (m_selectedGadget) m_selectedGadget->select(-1);
     m_selectedGadget = selectedGadget;
-    if (m_selectedGadget)
-      m_selectedGadget->select(id - m_selectedGadget->getId());
   }
+  if (!m_selectedGadget) return;
+  int handleId = id - m_selectedGadget->getId();
+  if (!m_selectedGadget->isSelected(handleId))
+    m_selectedGadget->select(handleId);
 }
 
 //---------------------------------------------------------------------------
@@ -1713,6 +1949,26 @@ FxGadget *FxGadgetController::allocateGadget(const TParamUIConcept &uiConcept) {
                                      uiConcept.m_params[1]);
     break;
   }
+
+  case TParamUIConcept::COMPASS: {
+    assert(uiConcept.m_params.size() == 1);
+    gadget = new CompassFxGadget(this, uiConcept.m_params[0]);
+    break;
+  }
+
+  case TParamUIConcept::COMPASS_SPIN: {
+    assert(uiConcept.m_params.size() == 1);
+    gadget = new CompassFxGadget(this, uiConcept.m_params[0], true);
+    break;
+  }
+
+  case TParamUIConcept::RAINBOW_WIDTH: {
+    assert(uiConcept.m_params.size() == 3);
+    gadget =
+        new RainbowWidthFxGadget(this, uiConcept.m_params[0],
+                                 uiConcept.m_params[1], uiConcept.m_params[2]);
+    break;
+  }
   default:
     break;
   }
@@ -1784,6 +2040,15 @@ EditToolGadgets::DragTool *FxGadgetController::createDragTool(int gadgetId) {
 //---------------------------------------------------------------------------
 
 TAffine FxGadgetController::getMatrix() {
+  TFx *fx = m_fxHandle ? m_fxHandle->getFx() : 0;
+  if (fx) {
+    int referenceColumnIndex = fx->getReferenceColumnIndex();
+    if (referenceColumnIndex == -1)
+      return m_tool->getMatrix().inv();
+    else if (referenceColumnIndex != m_tool->getColumnIndex())
+      return m_tool->getMatrix().inv() *
+             m_tool->getColumnMatrix(referenceColumnIndex, -1);
+  }
   return m_tool->getMatrix().inv() * m_tool->getCurrentColumnMatrix();
 }
 
@@ -1794,3 +2059,7 @@ int FxGadgetController::getCurrentFrame() const { return m_tool->getFrame(); }
 //---------------------------------------------------------------------------
 
 void FxGadgetController::invalidateViewer() { m_tool->invalidate(); }
+
+int FxGadgetController::getDevPixRatio() {
+  return getDevicePixelRatio(m_tool->getViewer()->viewerWidget());
+}
