@@ -603,6 +603,17 @@ void ToolUtils::TToolUndo::notifyImageChanged() const {
   }
 }
 
+//------------------------------------------------------------------------------------------
+
+void ToolUtils::TToolUndo::onAdd() {
+  // clean up the flags after registering undo
+  TTool::m_isLevelCreated     = false;
+  TTool::m_isFrameCreated     = false;
+  TTool::m_isLevelRenumbererd = false;
+}
+
+//------------------------------------------------------------------------------------------
+
 int ToolUtils::TToolUndo::m_idCount = 0;
 
 //================================================================================================
@@ -1489,7 +1500,9 @@ void ToolUtils::drawBalloon(const TPointD &pos, std::string text,
                             const TPixel32 &color, TPoint delta,
                             double pixelSize, bool isPicking,
                             std::vector<TRectD> *otherBalloons) {
-  int devPixRatio = getDevPixRatio();
+  TTool::Viewer *viewer =
+      TTool::getApplication()->getCurrentTool()->getTool()->getViewer();
+  int devPixRatio = getDevicePixelRatio(viewer->viewerWidget());
   QString qText   = QString::fromStdString(text);
   QFont font("Arial");  // ,QFont::Bold);
   font.setPixelSize(13 * devPixRatio);
@@ -1542,9 +1555,6 @@ void ToolUtils::drawBalloon(const TPointD &pos, std::string text,
   int y1 = textRect.bottom() + mrg;
 
   if (isPicking) {
-    TTool::Viewer *viewer =
-        TTool::getApplication()->getCurrentTool()->getTool()->getViewer();
-
     if (viewer->is3DView()) {
       double x0 = pos.x + textRect.left() * pixelSize,
              y0 = pos.y + delta.y * pixelSize;
@@ -1634,7 +1644,9 @@ void ToolUtils::drawBalloon(const TPointD &pos, std::string text,
 
 void ToolUtils::drawHook(const TPointD &pos, ToolUtils::HookType type,
                          bool highlighted, bool onionSkin) {
-  int devPixRatio = getDevPixRatio();
+  TTool::Viewer *viewer =
+      TTool::getApplication()->getCurrentTool()->getTool()->getViewer();
+  int devPixRatio = getDevicePixelRatio(viewer->viewerWidget());
   int r = 10, d = r + r;
   QImage image(d * devPixRatio, d * devPixRatio, QImage::Format_ARGB32);
   image.fill(Qt::transparent);
@@ -1819,6 +1831,15 @@ bool ToolUtils::doUpdateXSheet(TXshSimpleLevel *sl,
 
 bool ToolUtils::renumberForInsertFId(TXshSimpleLevel *sl, const TFrameId &fid,
                                      const TFrameId &maxFid, TXsheet *xsh) {
+  auto getNextLetter = [](const QString &letter) {
+    if (letter.isEmpty()) return QString('a');
+    if (letter == 'z' || letter == 'Z') return QString();
+    QByteArray byteArray = letter.toUtf8();
+    // return incrementing the last letter
+    byteArray.data()[byteArray.size() - 1]++;
+    return QString::fromUtf8(byteArray);
+  };
+
   std::vector<TFrameId> fids;
   std::vector<TFrameId> oldFrames;
   sl->getFids(oldFrames);
@@ -1832,10 +1853,10 @@ bool ToolUtils::renumberForInsertFId(TXshSimpleLevel *sl, const TFrameId &fid,
   for (auto itr = fidsSet.upper_bound(maxFid); itr != fidsSet.end(); ++itr) {
     if (*itr > tmpFid) break;
     fIdsToBeShifted.push_back(*itr);
-    if (fid.getLetter()) {
-      if ((*itr).getLetter() < 'z')
-        tmpFid = TFrameId((*itr).getNumber(),
-                          ((*itr).getLetter()) ? (*itr).getLetter() + 1 : 'a');
+    if (!fid.getLetter().isEmpty()) {
+      QString nextLetter = getNextLetter((*itr).getLetter());
+      if (!nextLetter.isEmpty())
+        tmpFid = TFrameId((*itr).getNumber(), nextLetter);
       else
         tmpFid = TFrameId((*itr).getNumber() + 1);
     } else
@@ -1846,11 +1867,10 @@ bool ToolUtils::renumberForInsertFId(TXshSimpleLevel *sl, const TFrameId &fid,
 
   for (TFrameId &tmpFid : fids) {
     if (fIdsToBeShifted.contains(tmpFid)) {
-      if (fid.getLetter()) {
-        if (tmpFid.getLetter() < 'z')
-          tmpFid =
-              TFrameId(tmpFid.getNumber(),
-                       (tmpFid.getLetter()) ? tmpFid.getLetter() + 1 : 'a');
+      if (!fid.getLetter().isEmpty()) {
+        QString nextLetter = getNextLetter(tmpFid.getLetter());
+        if (!nextLetter.isEmpty())
+          tmpFid = TFrameId(tmpFid.getNumber(), nextLetter);
         else
           tmpFid = TFrameId(tmpFid.getNumber() + 1);
       } else
