@@ -56,6 +56,7 @@ TEnv::IntVar BrushPressureSensitivity("InknpaintBrushPressureSensitivity", 1);
 TEnv::DoubleVar RasterBrushHardness("RasterBrushHardness", 100);
 TEnv::DoubleVar RasterBrushModifierSize("RasterBrushModifierSize", 0);
 TEnv::StringVar RasterBrushPreset("RasterBrushPreset", "<custom>");
+TEnv::IntVar BrushLockAlpha("InknpaintBrushLockAlpha", 0);
 
 //-------------------------------------------------------------------
 #define CUSTOM_WSTR L"<custom>"
@@ -436,26 +437,28 @@ class RasterBrushUndo final : public TRasterUndo {
   bool m_selective;
   bool m_isPaletteOrder;
   bool m_isPencil;
+  bool m_modifierLockAlpha;
 
 public:
   RasterBrushUndo(TTileSetCM32 *tileSet, const std::vector<TThickPoint> &points,
                   int styleId, bool selective, TXshSimpleLevel *level,
                   const TFrameId &frameId, bool isPencil, bool isFrameCreated,
-                  bool isLevelCreated, bool isPaletteOrder)
+                  bool isLevelCreated, bool isPaletteOrder, bool lockAlpha)
       : TRasterUndo(tileSet, level, frameId, isFrameCreated, isLevelCreated, 0)
       , m_points(points)
       , m_styleId(styleId)
       , m_selective(selective)
       , m_isPencil(isPencil)
-      , m_isPaletteOrder(isPaletteOrder) {}
+      , m_isPaletteOrder(isPaletteOrder)
+      , m_modifierLockAlpha(lockAlpha) {}
 
   void redo() const override {
     insertLevelAndFrameIfNeeded();
     TToonzImageP image = getImage();
     TRasterCM32P ras   = image->getRaster();
-    RasterStrokeGenerator m_rasterTrack(ras, BRUSH, NONE, m_styleId,
-                                        m_points[0], m_selective, 0,
-                                        !m_isPencil, m_isPaletteOrder);
+    RasterStrokeGenerator m_rasterTrack(
+        ras, BRUSH, NONE, m_styleId, m_points[0], m_selective, 0,
+        m_modifierLockAlpha, !m_isPencil, m_isPaletteOrder);
     if (m_isPaletteOrder) {
       QSet<int> aboveStyleIds;
       getAboveStyleIdSet(m_styleId, image->getPalette(), aboveStyleIds);
@@ -485,19 +488,22 @@ class RasterBluredBrushUndo final : public TRasterUndo {
   DrawOrder m_drawOrder;
   int m_maxThick;
   double m_hardness;
+  bool m_modifierLockAlpha;
 
 public:
   RasterBluredBrushUndo(TTileSetCM32 *tileSet,
                         const std::vector<TThickPoint> &points, int styleId,
-                        DrawOrder drawOrder, TXshSimpleLevel *level,
-                        const TFrameId &frameId, int maxThick, double hardness,
-                        bool isFrameCreated, bool isLevelCreated)
+                        DrawOrder drawOrder, bool lockAlpha,
+                        TXshSimpleLevel *level, const TFrameId &frameId,
+                        int maxThick, double hardness, bool isFrameCreated,
+                        bool isLevelCreated)
       : TRasterUndo(tileSet, level, frameId, isFrameCreated, isLevelCreated, 0)
       , m_points(points)
       , m_styleId(styleId)
       , m_drawOrder(drawOrder)
       , m_maxThick(maxThick)
-      , m_hardness(hardness) {}
+      , m_hardness(hardness)
+      , m_modifierLockAlpha(lockAlpha) {}
 
   void redo() const override {
     if (m_points.size() == 0) return;
@@ -520,7 +526,8 @@ public:
     points.push_back(m_points[0]);
     TRect bbox = brush.getBoundFromPoints(points);
     brush.addPoint(m_points[0], 1);
-    brush.updateDrawing(ras, ras, bbox, m_styleId, (int)m_drawOrder);
+    brush.updateDrawing(ras, ras, bbox, m_styleId, (int)m_drawOrder,
+                        m_modifierLockAlpha);
     if (m_points.size() > 1) {
       points.clear();
       points.push_back(m_points[0]);
@@ -528,7 +535,8 @@ public:
       bbox = brush.getBoundFromPoints(points);
       brush.addArc(m_points[0], (m_points[1] + m_points[0]) * 0.5, m_points[1],
                    1, 1);
-      brush.updateDrawing(ras, backupRas, bbox, m_styleId, (int)m_drawOrder);
+      brush.updateDrawing(ras, backupRas, bbox, m_styleId, (int)m_drawOrder,
+                          m_modifierLockAlpha);
       int i;
       for (i = 1; i + 2 < (int)m_points.size(); i = i + 2) {
         points.clear();
@@ -537,7 +545,8 @@ public:
         points.push_back(m_points[i + 2]);
         bbox = brush.getBoundFromPoints(points);
         brush.addArc(m_points[i], m_points[i + 1], m_points[i + 2], 1, 1);
-        brush.updateDrawing(ras, backupRas, bbox, m_styleId, (int)m_drawOrder);
+        brush.updateDrawing(ras, backupRas, bbox, m_styleId, (int)m_drawOrder,
+                            m_modifierLockAlpha);
       }
     }
     ToolUtils::updateSaveBox();
@@ -655,7 +664,8 @@ static void CatmullRomInterpolate(const TThickPoint &P0, const TThickPoint &P1,
 
 //--------------------------------------------------------------------------------------------------
 
-static void Smooth(std::vector<TThickPoint> &points, int radius) {
+static void Smooth(std::vector<TThickPoint> &points, const int radius,
+                   const int readIndex, const int level) {
   int n = (int)points.size();
   if (radius < 1 || n < 3) {
     return;
@@ -665,7 +675,10 @@ static void Smooth(std::vector<TThickPoint> &points, int radius) {
 
   float d = 1.0f / (radius * 2 + 1);
 
-  for (int i = 1; i < n - 1; ++i) {
+  int endSamples = 10;
+  int startId    = std::max(readIndex - endSamples * 3 - radius * level, 1);
+
+  for (int i = startId; i < n - 1; ++i) {
     int lower = i - radius;
     int upper = i + radius;
 
@@ -692,21 +705,23 @@ static void Smooth(std::vector<TThickPoint> &points, int radius) {
     result.push_back(total);
   }
 
-  for (int i = 1; i < n - 1; ++i) {
-    points[i].x     = result[i - 1].x;
-    points[i].y     = result[i - 1].y;
-    points[i].thick = result[i - 1].thick;
+  auto result_itr = result.begin();
+  for (int i = startId; i < n - 1; ++i, ++result_itr) {
+    points[i].x     = (*result_itr).x;
+    points[i].y     = (*result_itr).y;
+    points[i].thick = (*result_itr).thick;
   }
 
   if (points.size() >= 3) {
     std::vector<TThickPoint> pts;
-    CatmullRomInterpolate(points[0], points[0], points[1], points[2], 10, pts);
+    CatmullRomInterpolate(points[0], points[0], points[1], points[2],
+                          endSamples, pts);
     std::vector<TThickPoint>::iterator it = points.begin() + 1;
     points.insert(it, pts.begin(), pts.end());
 
     pts.clear();
     CatmullRomInterpolate(points[n - 3], points[n - 2], points[n - 1],
-                          points[n - 1], 10, pts);
+                          points[n - 1], endSamples, pts);
     it = points.begin();
     it += n - 1;
     points.insert(it, pts.begin(), pts.end());
@@ -721,6 +736,8 @@ void SmoothStroke::beginStroke(int smooth) {
   m_readIndex   = -1;
   m_rawPoints.clear();
   m_outputPoints.clear();
+  m_resampledIndex = 0;
+  m_resampledPoints.clear();
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -749,6 +766,8 @@ void SmoothStroke::clearPoints() {
   m_readIndex   = -1;
   m_outputPoints.clear();
   m_rawPoints.clear();
+  m_resampledIndex = 0;
+  m_resampledPoints.clear();
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -781,26 +800,40 @@ void SmoothStroke::generatePoints() {
     return;
   }
 
-  std::vector<TThickPoint> smoothedPoints;
+  std::vector<TThickPoint> smoothedPoints = m_resampledPoints;
   // Add more stroke samples before applying the smoothing
   // This is because the raw inputs points are too few to support smooth result,
   // especially on stroke ends
-  smoothedPoints.push_back(m_rawPoints.front());
-  for (int i = 1; i < n; ++i) {
-    const TThickPoint &p1 = m_rawPoints[i - 1];
-    const TThickPoint &p2 = m_rawPoints[i];
-    const TThickPoint &p0 = i - 2 >= 0 ? m_rawPoints[i - 2] : p1;
-    const TThickPoint &p3 = i + 1 < n ? m_rawPoints[i + 1] : p2;
 
-    int samples = 8;
-    CatmullRomInterpolate(p0, p1, p2, p3, samples, smoothedPoints);
-    smoothedPoints.push_back(p2);
+  int resampleStartId = m_resampledIndex;
+  for (int i = resampleStartId; i < n - 1; ++i) {
+    const TThickPoint &p1 = m_rawPoints[i];
+    const TThickPoint &p2 = m_rawPoints[i + 1];
+    const TThickPoint &p0 = i - 1 >= 0 ? m_rawPoints[i - 1] : p1;
+    const TThickPoint &p3 = i + 2 < n ? m_rawPoints[i + 2] : p2;
+
+    std::vector<TThickPoint> tmpResampled;
+    tmpResampled.push_back(p1);
+    // define subsample amount according to distance between points
+    int samples = std::min((int)tdistance(p1, p2), 8);
+    if (samples >= 1)
+      CatmullRomInterpolate(p0, p1, p2, p3, samples, tmpResampled);
+
+    if (i + 2 < n) {
+      m_resampledIndex = i + 1;
+      std::copy(tmpResampled.begin(), tmpResampled.end(),
+                std::back_inserter(m_resampledPoints));
+    }
+    std::copy(tmpResampled.begin(), tmpResampled.end(),
+              std::back_inserter(smoothedPoints));
   }
+  smoothedPoints.push_back(m_rawPoints.back());
   // Apply the 1D box filter
   // Multiple passes result in better quality and fix the stroke ends break
   // issue
-  for (int i = 0; i < 3; ++i) {
-    Smooth(smoothedPoints, m_smooth);
+  // level is passed to define range where the points are smoothed
+  for (int level = 2; level >= 0; --level) {
+    Smooth(smoothedPoints, m_smooth, m_readIndex, level);
   }
   // Compare the new smoothed stroke with old one
   // Enable the output for unchanged parts
@@ -840,7 +873,8 @@ ToonzRasterBrushTool::ToonzRasterBrushTool(std::string name, int targetType)
     , m_presetsLoaded(false)
     , m_targetType(targetType)
     , m_workingFrameId(TFrameId())
-    , m_notifier(0) {
+    , m_notifier(0)
+    , m_modifierLockAlpha("Lock Alpha", false) {
   bind(targetType);
 
   m_rasThickness.setNonLinearSlider();
@@ -850,6 +884,7 @@ ToonzRasterBrushTool::ToonzRasterBrushTool(std::string name, int targetType)
   m_prop[0].bind(m_smooth);
   m_prop[0].bind(m_drawOrder);
   m_prop[0].bind(m_modifierSize);
+  m_prop[0].bind(m_modifierLockAlpha);
   m_prop[0].bind(m_pencil);
   m_pencil.setId("PencilMode");
 
@@ -864,6 +899,7 @@ ToonzRasterBrushTool::ToonzRasterBrushTool(std::string name, int targetType)
   m_preset.setId("BrushPreset");
   m_preset.addValue(CUSTOM_WSTR);
   m_pressure.setId("PressureSensitivity");
+  m_modifierLockAlpha.setId("LockAlpha");
 }
 
 //-------------------------------------------------------------------------------------------------------
@@ -1057,6 +1093,7 @@ void ToonzRasterBrushTool::updateTranslation() {
   m_preset.setItemUIName(CUSTOM_WSTR, tr("<custom>"));
   m_pencil.setQStringName(tr("Pencil"));
   m_pressure.setQStringName(tr("Pressure"));
+  m_modifierLockAlpha.setQStringName(tr("Lock Alpha"));
 }
 
 //---------------------------------------------------------------------------------------------------
@@ -1298,7 +1335,7 @@ void ToonzRasterBrushTool::leftButtonDown(const TPointD &pos,
       if (!updateRect.isEmpty()) {
         // ras->extract(updateRect)->copy(m_workRas->extract(updateRect));
         m_toonz_brush->updateDrawing(ri->getRaster(), m_backupRas, m_strokeRect,
-                                     m_styleId);
+                                     m_styleId, m_modifierLockAlpha.getValue());
       }
       m_lastRect = m_strokeRect;
 
@@ -1317,7 +1354,8 @@ void ToonzRasterBrushTool::leftButtonDown(const TPointD &pos,
                              thickness);
       m_rasterTrack = new RasterStrokeGenerator(
           ras, BRUSH, NONE, m_styleId, thickPoint, drawOrder != OverAll, 0,
-          !m_pencil.getValue(), drawOrder == PaletteOrder);
+          m_modifierLockAlpha.getValue(), !m_pencil.getValue(),
+          drawOrder == PaletteOrder);
 
       if (drawOrder == PaletteOrder)
         m_rasterTrack->setAboveStyleIds(aboveStyleIds);
@@ -1347,7 +1385,8 @@ void ToonzRasterBrushTool::leftButtonDown(const TPointD &pos,
       m_tileSaver->save(m_strokeRect);
       m_bluredBrush->addPoint(point, 1);
       m_bluredBrush->updateDrawing(ri->getRaster(), m_backupRas, m_strokeRect,
-                                   m_styleId, drawOrder);
+                                   m_styleId, drawOrder,
+                                   m_modifierLockAlpha.getValue());
       m_lastRect = m_strokeRect;
 
       std::vector<TThickPoint> pts;
@@ -1400,7 +1439,7 @@ void ToonzRasterBrushTool::leftButtonDrag(const TPointD &pos,
     if (!updateRect.isEmpty()) {
       // ras->extract(updateRect)->copy(m_workRaster->extract(updateRect));
       m_toonz_brush->updateDrawing(ras, m_backupRas, m_strokeSegmentRect,
-                                   m_styleId);
+                                   m_styleId, m_modifierLockAlpha.getValue());
     }
     m_lastRect = m_strokeRect;
 
@@ -1487,7 +1526,8 @@ void ToonzRasterBrushTool::leftButtonDrag(const TPointD &pos,
       invalidateRect += ToolUtils::getBounds(points, maxThickness) - rasCenter;
 
       m_bluredBrush->updateDrawing(ti->getRaster(), m_backupRas, bbox,
-                                   m_styleId, m_drawOrder.getIndex());
+                                   m_styleId, m_drawOrder.getIndex(),
+                                   m_modifierLockAlpha.getValue());
       m_strokeRect += bbox;
     }
   }
@@ -1554,7 +1594,7 @@ void ToonzRasterBrushTool::finishRasterBrush(const TPointD &pos,
     if (!updateRect.isEmpty()) {
       // ras->extract(updateRect)->copy(m_workRaster->extract(updateRect));
       m_toonz_brush->updateDrawing(ras, m_backupRas, m_strokeSegmentRect,
-                                   m_styleId);
+                                   m_styleId, m_modifierLockAlpha.getValue());
     }
     TPointD thickOffset(m_maxCursorThick * 0.5,
                         m_maxCursorThick * 0.5);  // TODO
@@ -1627,7 +1667,8 @@ void ToonzRasterBrushTool::finishRasterBrush(const TPointD &pos,
           m_tileSet, m_rasterTrack->getPointsSequence(),
           m_rasterTrack->getStyleId(), m_rasterTrack->isSelective(),
           simLevel.getPointer(), frameId, m_pencil.getValue(), m_isFrameCreated,
-          m_isLevelCreated, m_rasterTrack->isPaletteOrder()));
+          m_isLevelCreated, m_rasterTrack->isPaletteOrder(),
+          m_rasterTrack->isAlphaLocked()));
     }
     delete m_rasterTrack;
     m_rasterTrack = 0;
@@ -1686,7 +1727,8 @@ void ToonzRasterBrushTool::finishRasterBrush(const TPointD &pos,
             ToolUtils::getBounds(points, maxThickness) - rasCenter;
 
         m_bluredBrush->updateDrawing(ti->getRaster(), m_backupRas, bbox,
-                                     m_styleId, m_drawOrder.getIndex());
+                                     m_styleId, m_drawOrder.getIndex(),
+                                     m_modifierLockAlpha.getValue());
         m_strokeRect += bbox;
       }
       TThickPoint point = pts.back();
@@ -1701,7 +1743,8 @@ void ToonzRasterBrushTool::finishRasterBrush(const TPointD &pos,
       m_tileSaver->save(bbox);
       m_bluredBrush->addArc(points[0], points[1], points[2], 1, 1);
       m_bluredBrush->updateDrawing(ti->getRaster(), m_backupRas, bbox,
-                                   m_styleId, m_drawOrder.getIndex());
+                                   m_styleId, m_drawOrder.getIndex(),
+                                   m_modifierLockAlpha.getValue());
 
       invalidateRect += ToolUtils::getBounds(points, maxThickness) - rasCenter;
 
@@ -1717,8 +1760,9 @@ void ToonzRasterBrushTool::finishRasterBrush(const TPointD &pos,
     if (m_tileSet->getTileCount() > 0) {
       TUndoManager::manager()->add(new RasterBluredBrushUndo(
           m_tileSet, m_points, m_styleId, (DrawOrder)m_drawOrder.getIndex(),
-          simLevel.getPointer(), frameId, m_rasThickness.getValue().second,
-          m_hardness.getValue() * 0.01, m_isFrameCreated, m_isLevelCreated));
+          m_modifierLockAlpha.getValue(), simLevel.getPointer(), frameId,
+          m_rasThickness.getValue().second, m_hardness.getValue() * 0.01,
+          m_isFrameCreated, m_isLevelCreated));
     }
   }
   delete m_tileSaver;
@@ -1968,6 +2012,7 @@ bool ToonzRasterBrushTool::onPropertyChanged(std::string propertyName) {
   BrushPressureSensitivity = m_pressure.getValue();
   RasterBrushHardness      = m_hardness.getValue();
   RasterBrushModifierSize  = m_modifierSize.getValue();
+  BrushLockAlpha           = m_modifierLockAlpha.getValue();
 
   // Recalculate/reset based on changed settings
   if (propertyName == m_rasThickness.getName()) {
@@ -2038,6 +2083,7 @@ void ToonzRasterBrushTool::loadPreset() {
     m_pencil.setValue(preset.m_pencil);
     m_pressure.setValue(preset.m_pressure);
     m_modifierSize.setValue(preset.m_modifierSize);
+    m_modifierLockAlpha.setValue(preset.m_modifierLockAlpha);
 
     // Recalculate based on updated presets
     m_minThick = m_rasThickness.getValue().first;
@@ -2059,12 +2105,13 @@ void ToonzRasterBrushTool::addPreset(QString name) {
   preset.m_min = m_rasThickness.getValue().first;
   preset.m_max = m_rasThickness.getValue().second;
 
-  preset.m_smooth       = m_smooth.getValue();
-  preset.m_hardness     = m_hardness.getValue();
-  preset.m_drawOrder    = m_drawOrder.getIndex();
-  preset.m_pencil       = m_pencil.getValue();
-  preset.m_pressure     = m_pressure.getValue();
-  preset.m_modifierSize = m_modifierSize.getValue();
+  preset.m_smooth            = m_smooth.getValue();
+  preset.m_hardness          = m_hardness.getValue();
+  preset.m_drawOrder         = m_drawOrder.getIndex();
+  preset.m_pencil            = m_pencil.getValue();
+  preset.m_pressure          = m_pressure.getValue();
+  preset.m_modifierSize      = m_modifierSize.getValue();
+  preset.m_modifierLockAlpha = m_modifierLockAlpha.getValue();
 
   // Pass the preset to the manager
   m_presetsManager.addPreset(preset);
@@ -2102,6 +2149,7 @@ void ToonzRasterBrushTool::loadLastBrush() {
   m_pressure.setValue(BrushPressureSensitivity ? 1 : 0);
   m_smooth.setValue(BrushSmooth);
   m_modifierSize.setValue(RasterBrushModifierSize);
+  m_modifierLockAlpha.setValue(BrushLockAlpha ? 1 : 0);
 
   // Recalculate based on prior values
   m_minThick = m_rasThickness.getValue().first;
