@@ -109,7 +109,7 @@ ComboViewerPanel::ComboViewerPanel(QWidget *parent, Qt::WFlags flags)
   //  This code should be removed after updating Qt.
   //  Qt may crash in handling WM_SIZE of m_sceneViewer in splash.finish(&w)
   //  in main.cpp. To suppress sending WM_SIZE, set window position here.
-  //  WM_SIZE will not be sent if window poistion is not changed.
+  //  WM_SIZE will not be sent if window position is not changed.
   ::SetWindowPos(reinterpret_cast<HWND>(m_sceneViewer->winId()), HWND_TOP, 0, 0,
                  0, 0, SWP_NOMOVE | SWP_NOSIZE);
 #endif
@@ -286,10 +286,12 @@ void ComboViewerPanel::onShowHideActionTriggered(QAction *act) {
 
 //-----------------------------------------------------------------------------
 
-void ComboViewerPanel::onDrawFrame(
-    int frame, const ImagePainter::VisualSettings &settings) {
+void ComboViewerPanel::onDrawFrame(int frame,
+                                   const ImagePainter::VisualSettings &settings,
+                                   QElapsedTimer *, qint64) {
   TApp *app = TApp::instance();
   m_sceneViewer->setVisual(settings);
+
   TFrameHandle *frameHandle = app->getCurrentFrame();
 
   if (m_sceneViewer->isPreviewEnabled()) {
@@ -644,13 +646,12 @@ void ComboViewerPanel::changeWindowTitle() {
     name = name + tr("   ::   Level: ") + imageName;
 
     if (!m_sceneViewer->is3DView()) {
-      TAffine aff                             = m_sceneViewer->getViewMatrix();
+      TAffine aff = m_sceneViewer->getViewMatrix() *
+                    m_sceneViewer->getNormalZoomScale().inv();
       if (m_sceneViewer->getIsFlippedX()) aff = aff * TScale(-1, 1);
       if (m_sceneViewer->getIsFlippedY()) aff = aff * TScale(1, -1);
-      name                                    = name + "  ::  Zoom : " +
-             QString::number((int)(100.0 * sqrt(aff.det()) *
-                                   m_sceneViewer->getDpiFactor())) +
-             "%";
+      name = name + "  ::  Zoom : " +
+             QString::number(tround(100.0 * sqrt(aff.det()))) + "%";
     }
 
     // If the current level exists and some option is set in the preference,
@@ -659,19 +660,17 @@ void ComboViewerPanel::changeWindowTitle() {
                  ->isActualPixelViewOnSceneEditingModeEnabled() &&
              TApp::instance()->getCurrentLevel()->getSimpleLevel() &&
              !CleanupPreviewCheck::instance()
-                  ->isEnabled()  // cleanup preview must be OFF
-             &&
-             !CameraTestCheck::instance()  // camera test mode must be OFF
-                                           // neither
-                  ->isEnabled() &&
+                  ->isEnabled()               // cleanup preview must be OFF
+             && !CameraTestCheck::instance()  // camera test mode must be OFF
+                                              // neither
+                     ->isEnabled() &&
              !m_sceneViewer->is3DView()) {
-      TAffine aff                             = m_sceneViewer->getViewMatrix();
+      TAffine aff = m_sceneViewer->getViewMatrix() *
+                    m_sceneViewer->getNormalZoomScale().inv();
       if (m_sceneViewer->getIsFlippedX()) aff = aff * TScale(-1, 1);
       if (m_sceneViewer->getIsFlippedY()) aff = aff * TScale(1, -1);
-      name                                    = name + "  ::  Zoom : " +
-             QString::number((int)(100.0 * sqrt(aff.det()) *
-                                   m_sceneViewer->getDpiFactor())) +
-             "%";
+      name = name + "  ::  Zoom : " +
+             QString::number(tround(100.0 * sqrt(aff.det()))) + "%";
     }
 
   }
@@ -685,13 +684,12 @@ void ComboViewerPanel::changeWindowTitle() {
 
       name = name + tr("Level: ") + imageName;
       if (!m_sceneViewer->is3DView()) {
-        TAffine aff = m_sceneViewer->getViewMatrix();
+        TAffine aff = m_sceneViewer->getViewMatrix() *
+                      m_sceneViewer->getNormalZoomScale().inv();
         if (m_sceneViewer->getIsFlippedX()) aff = aff * TScale(-1, 1);
         if (m_sceneViewer->getIsFlippedY()) aff = aff * TScale(1, -1);
-        name                                    = name + "  ::  Zoom : " +
-               QString::number((int)(100.0 * sqrt(aff.det()) *
-                                     m_sceneViewer->getDpiFactor())) +
-               "%";
+        name = name + "  ::  Zoom : " +
+               QString::number(tround(100.0 * sqrt(aff.det()))) + "%";
       }
     }
   }
