@@ -338,7 +338,7 @@ void FileBrowser::storeFolderHistory() {
     m_indexHistoryList << currentModelIndex;
     m_currentPosition++;
   }
-  // If the next hitory item is the same as the current one, just move to it
+  // If the next history item is the same as the current one, just move to it
   else if (m_indexHistoryList[m_currentPosition + 1] == currentModelIndex) {
     m_currentPosition++;
   }
@@ -536,7 +536,7 @@ void FileBrowser::refreshCurrentFolderItems() {
   if (parentFp != TFilePath("") && parentFp != m_folder)
     m_items.push_back(Item(parentFp, true, false));
 
-  // register the all folder items by using the folde tree model
+  // register all folder items by using the folder tree model
   DvDirModel *model        = DvDirModel::instance();
   QModelIndex currentIndex = model->getIndexByPath(m_folder);
   if (currentIndex.isValid()) {
@@ -705,7 +705,7 @@ void FileBrowser::setFolder(const TFilePath &fp, bool expandNode,
 }
 
 //-----------------------------------------------------------------------------
-/*! process when inputting the folder which is not regitered in the folder tree
+/*! process when inputting the folder which is not registered in the folder tree
    (e.g. UNC path in Windows)
  */
 void FileBrowser::setUnregisteredFolder(const TFilePath &fp) {
@@ -909,7 +909,7 @@ QVariant FileBrowser::getItemData(int index, DataType dataType,
   if (index < 0 || index >= (int)m_items.size()) return QVariant();
   Item &item = m_items[index];
   if (dataType == Name) {
-    // show two dots( ".." ) for the paret directory item
+    // show two dots( ".." ) for the parent directory item
     if (item.m_path == m_folder.getParentDir())
       return QString("..");
     else
@@ -1192,7 +1192,9 @@ QMenu *FileBrowser::getContextMenu(QWidget *parent, int index) {
   }
 
   for (i = 0; i < files.size(); i++)
-    if (!TFileType::isViewable(TFileType::getInfo(files[i]))) break;
+    if (!TFileType::isViewable(TFileType::getInfo(files[i])) &&
+        files[i].getType() != "tpl")
+      break;
   if (i == files.size()) {
     std::string type = files[0].getType();
     for (j = 0; j < files.size(); j++)
@@ -2076,7 +2078,7 @@ void FileBrowser::onSelectedItems(const std::set<int> &indexes) {
   }
 
   // reuse the list of TFrameId in order to skip loadInfo() when loading the
-  // level with sequencial frames.
+  // level with sequential frames.
   emit filePathsSelected(filePaths, frameIDs);
 }
 
