@@ -702,15 +702,15 @@ void FilmstripFrames::paintEvent(QPaintEvent *evt) {
           fid.getNumber() == TFrameId::NO_FRAME) {
         text = QString("Single Frame");
       }
-      // for sequencial frame (with letter)
+      // for sequential frame (with letter)
       else if (Preferences::instance()->isShowFrameNumberWithLettersEnabled()) {
         text = fidToFrameNumberWithLetter(fid.getNumber());
       }
-      // for sequencial frame
+      // for sequential frame
       else {
-        char letter = fid.getLetter();
-        text        = QString::number(fid.getNumber()).rightJustified(4, '0') +
-               (letter != '\0' ? QString(letter) : "");
+        QString letter = fid.getLetter();
+        text = QString::number(fid.getNumber()).rightJustified(4, '0') +
+               (!letter.isEmpty() ? letter : "");
       }
       p.drawText(tmp_frameRect.adjusted(0, 0, -3, 2), text,
                  QTextOption(Qt::AlignRight | Qt::AlignBottom));
@@ -1973,7 +1973,7 @@ void Filmstrip::load(QSettings &settings) {
 //-----------------------------------------------------------------------------
 
 InbetweenDialog::InbetweenDialog(QWidget *parent)
-    : Dialog(TApp::instance()->getMainWindow(), true, "InBeetween") {
+    : Dialog(TApp::instance()->getMainWindow(), true, "InBetween") {
   setWindowTitle(tr("Inbetween"));
 
   QString linear(tr("Linear"));
