@@ -163,34 +163,33 @@ inline TRectD getImageBoundsD(const TImageP &img) {
 FlipBook::FlipBook(QWidget *parent, QString viewerTitle,
                    std::vector<int> flipConsoleButtonMask, UCHAR flags,
                    bool isColorModel)  //, bool showOnlyPlayBackgroundButton)
-    : QWidget(parent),
-      m_viewerTitle(viewerTitle),
-      m_levelNames(),
-      m_levels(),
-      m_playSound(false),
-      m_snd(0),
-      m_player(0)
-      //, m_doCompare(false)
-      ,
-      m_currentFrameToSave(0),
-      m_lw(),
-      m_lr(),
-      m_loadPopup(0),
-      m_savePopup(0),
-      m_shrink(1),
-      m_isPreviewFx(false),
-      m_previewedFx(0),
-      m_previewXsh(0),
-      m_previewUpdateTimer(this),
-      m_xl(0),
-      m_title1(),
-      m_poolIndex(-1),
-      m_freezed(false),
-      m_loadbox(),
-      m_dim(),
-      m_loadboxes(),
-      m_freezeButton(0),
-      m_flags(flags) {
+    : QWidget(parent)
+    , m_viewerTitle(viewerTitle)
+    , m_levelNames()
+    , m_levels()
+    , m_playSound(false)
+    , m_snd(0)
+    , m_player(0)
+    //, m_doCompare(false)
+    , m_currentFrameToSave(0)
+    , m_lw()
+    , m_lr()
+    , m_loadPopup(0)
+    , m_savePopup(0)
+    , m_shrink(1)
+    , m_isPreviewFx(false)
+    , m_previewedFx(0)
+    , m_previewXsh(0)
+    , m_previewUpdateTimer(this)
+    , m_xl(0)
+    , m_title1()
+    , m_poolIndex(-1)
+    , m_freezed(false)
+    , m_loadbox()
+    , m_dim()
+    , m_loadboxes()
+    , m_freezeButton(0)
+    , m_flags(flags) {
   setAcceptDrops(true);
   setFocusPolicy(Qt::StrongFocus);
 
@@ -792,18 +791,24 @@ void FlipBook::onButtonPressed(FlipConsole::EGadget button) {
     TImageP clonedImg;
     if (ri)
       clonedImg = TRasterImageP(ri->getRaster()->clone());
-    else
+    else {
       clonedImg = TToonzImageP(ti->getRaster()->clone(), ti->getSavebox());
+      clonedImg->setPalette(ti->getPalette());
+    }
     TImageCache::instance()->add(QString("TnzCompareImg"), clonedImg);
+    // to update the histogram of compare snapshot image
+    m_imageViewer->invalidateCompHisto();
     break;
   }
 
   case FlipConsole::eCompare:
-    if ((TVectorImageP)getCurrentImage(m_flipConsole->getCurrentFrame())) {
+    if (m_flipConsole->isChecked(FlipConsole::eCompare) &&
+        (TVectorImageP)getCurrentImage(m_flipConsole->getCurrentFrame())) {
       DVGui::warning(
           tr("It is not possible to take or compare snapshots for Toonz vector "
              "levels."));
-      m_flipConsole->setChecked(FlipConsole::eCompare, false);
+      // cancel the button pressing
+      m_flipConsole->pressButton(FlipConsole::eCompare);
       return;
     }
     break;
@@ -1103,7 +1108,7 @@ void FlipBook::setLevel(const TFilePath &fp, TPalette *palette, int from,
         fromIndex = level->begin()->first.getNumber();
         toIndex   = (--level->end())->first.getNumber();
         if (m_imageViewer->isColorModel())
-          current           = m_flipConsole->getCurrentFrame();
+          current = m_flipConsole->getCurrentFrame();
         incrementalIndexing = true;
       } else {
         TLevel::Iterator it = level->begin();
@@ -1141,10 +1146,9 @@ void FlipBook::setLevel(const TFilePath &fp, TPalette *palette, int from,
       levelToPush.m_incrementalIndexing = incrementalIndexing;
 
       int formatIdx = Preferences::instance()->matchLevelFormat(fp);
-      if (formatIdx >= 0 &&
-          Preferences::instance()
-              ->levelFormat(formatIdx)
-              .m_options.m_premultiply) {
+      if (formatIdx >= 0 && Preferences::instance()
+                                ->levelFormat(formatIdx)
+                                .m_options.m_premultiply) {
         levelToPush.m_premultiply = true;
       }
 
@@ -1206,7 +1210,7 @@ void FlipBook::setLevel(const TFilePath &fp, TPalette *palette, int from,
                                  m_framesCount);                         // to
       }
 
-      // An old archived bug says that simulatenous open for read of the same
+      // An old archived bug says that simultaneous open for read of the same
       // tlv are not allowed...
       // if(m_lr && m_lr->getFilePath().getType()=="tlv")
       //  m_lr = TLevelReaderP();
@@ -1413,7 +1417,7 @@ void FlipBook::freezePreview() {
 
   m_freezed = true;
 
-  // sync the button state when triggered by shotcut
+  // sync the button state when triggered by shortcut
   if (m_freezeButton) m_freezeButton->setPressed(true);
 }
 
@@ -1426,7 +1430,7 @@ void FlipBook::unfreezePreview() {
 
   m_freezed = false;
 
-  // sync the button state when triggered by shotcut
+  // sync the button state when triggered by shortcut
   if (m_freezeButton) m_freezeButton->setPressed(false);
 }
 
@@ -1595,6 +1599,9 @@ TImageP FlipBook::getCurrentImage(int frame) {
       lx = m_loadbox.getLx();
     }
 
+    if (Preferences::instance()->is30bitDisplayEnabled())
+      ir->enable16BitRead(true);
+
     TImageP img = ir->load();
 
     if (img) {
@@ -1637,7 +1644,7 @@ TImageP FlipBook::getCurrentImage(int frame) {
       m_loadboxes[id] = showSub ? m_loadbox : TRect();
     }
 
-    // An old archived bug says that simulatenous open for read of the same tlv
+    // An old archived bug says that simultaneous open for read of the same tlv
     // are not allowed...
     // if(fp.getType()=="tlv")
     //  m_lr = TLevelReaderP();
@@ -1661,9 +1668,11 @@ else*/
 
 /*! Set current level frame to image viewer. Add the view image in cache.
  */
-void FlipBook::onDrawFrame(int frame, const ImagePainter::VisualSettings &vs) {
+void FlipBook::onDrawFrame(int frame, const ImagePainter::VisualSettings &vs,
+                           QElapsedTimer *timer, qint64 targetInstant) {
   try {
     m_imageViewer->setVisual(vs);
+    m_imageViewer->setTimerAndTargetInstant(timer, targetInstant);
 
     TImageP img = getCurrentImage(frame);
 
@@ -2108,13 +2117,13 @@ QPointF newViewerGeomCenter(
 
 //-----------------------------------------------------------------------------
 
-void FlipBook::onDoubleClick(QMouseEvent *me) {
+void FlipBook::adaptGeometryToCurrentSize() {
   TImageP img(m_imageViewer->getImage());
   if (!img) return;
 
   TAffine toWidgetRef(m_imageViewer->getImgToWidgetAffine());
-  TRectD pixGeomD(TScale(1.0 / (double)getDevPixRatio()) * toWidgetRef *
-                  getImageBoundsD(img));
+  TRectD pixGeomD(TScale(1.0 / (double)getDevicePixelRatio(this)) *
+                  toWidgetRef * getImageBoundsD(img));
   // TRectD pixGeomD(toWidgetRef  * getImageBoundsD(img));
   TRect pixGeom(tceil(pixGeomD.x0), tceil(pixGeomD.y0), tfloor(pixGeomD.x1) - 1,
                 tfloor(pixGeomD.y1) - 1);
@@ -2135,6 +2144,17 @@ void FlipBook::onDoubleClick(QMouseEvent *me) {
 
 //-----------------------------------------------------------------------------
 
+void FlipBook::onDoubleClick(QMouseEvent *me) { adaptGeometryToCurrentSize(); }
+
+//-----------------------------------------------------------------------------
+
+void FlipBook::zoomAndAdaptGeometry(bool forward) {
+  m_imageViewer->zoomQt(forward, false);
+  adaptGeometryToCurrentSize();
+}
+
+//-----------------------------------------------------------------------------
+
 void FlipBook::minimize(bool doMinimize) {
   m_imageViewer->setVisible(!doMinimize);
   m_flipConsole->showHideAllParts(!doMinimize);
@@ -2146,7 +2166,7 @@ void FlipBook::minimize(bool doMinimize) {
 */
 void FlipBook::loadAndCacheAllTlvImages(Level level, int fromFrame,
                                         int toFrame) {
-  TFilePath fp                                   = level.m_fp;
+  TFilePath fp = level.m_fp;
   if (!m_lr || (fp != m_lr->getFilePath())) m_lr = TLevelReaderP(fp);
   if (!m_lr) return;
 
@@ -2218,12 +2238,12 @@ void FlipBook::loadAndCacheAllTlvImages(Level level, int fromFrame,
 FlipBook *viewFile(const TFilePath &path, int from, int to, int step,
                    int shrink, TSoundTrack *snd, FlipBook *flipbook,
                    bool append, bool isToonzOutput) {
-  // In case the step and shrink informations are invalid, load them from
+  // In case the step and shrink information is invalid, load them from
   // preferences
   if (step == -1 || shrink == -1) {
     int _step = 1, _shrink = 1;
     Preferences::instance()->getViewValues(_shrink, _step);
-    if (step == -1) step     = _step;
+    if (step == -1) step = _step;
     if (shrink == -1) shrink = _shrink;
   }
 
