@@ -27,7 +27,11 @@ public:
   void setImage(TImageP image);
 
   void updateInfo(const TPixel32 &pix, const TPointD &imagePos);
+  void updateInfo(const TPixel64 &pix, const TPointD &imagePos);
   void updateAverageColor(const TPixel32 &pix);
+  void updateAverageColor(const TPixel64 &pix);
+  void setShowCompare(bool on);
+  void invalidateCompHisto();
 };
 
 //=============================================================================
