@@ -5,6 +5,8 @@
 // Tnz6 includes
 #include "menubarcommandids.h"
 #include "tapp.h"
+#include "levelcommand.h"
+#include "formatsettingspopups.h"
 
 // TnzTools includes
 #include "tools/toolhandle.h"
@@ -34,6 +36,8 @@
 #include "toonz/palettecontroller.h"
 #include "toonz/tproject.h"
 #include "toonz/namebuilder.h"
+#include "toonz/childstack.h"
+#include "toutputproperties.h"
 
 // TnzCore includes
 #include "tsystem.h"
@@ -175,6 +179,10 @@ LevelCreatePopup::LevelCreatePopup()
   m_dpiLabel    = new QLabel(tr("DPI:"));
   m_dpiFld      = new DoubleLineEdit(0, 66.76);
 
+  m_rasterFormatLabel = new QLabel(tr("Format:"));
+  m_rasterFormatOm    = new QComboBox();
+  m_frameFormatBtn    = new QPushButton(tr("Frame Format"));
+
   QPushButton *okBtn     = new QPushButton(tr("OK"), this);
   QPushButton *cancelBtn = new QPushButton(tr("Cancel"), this);
   QPushButton *applyBtn  = new QPushButton(tr("Apply"), this);
@@ -201,6 +209,11 @@ LevelCreatePopup::LevelCreatePopup()
   m_heightFld->setRange(0.1, (std::numeric_limits<double>::max)());
   m_dpiFld->setRange(0.1, (std::numeric_limits<double>::max)());
 
+  m_rasterFormatOm->addItem("tif", "tif");
+  m_rasterFormatOm->addItem("png", "png");
+  m_rasterFormatOm->setCurrentIndex(m_rasterFormatOm->findData(
+      Preferences::instance()->getDefRasterFormat()));
+
   okBtn->setDefault(true);
 
   //--- layout
@@ -243,15 +256,21 @@ LevelCreatePopup::LevelCreatePopup()
                         Qt::AlignRight | Qt::AlignVCenter);
       guiLay->addWidget(m_pathFld, 4, 1, 1, 4);
 
+      // Format options (for Raster/Scan levels)
+      guiLay->addWidget(m_rasterFormatLabel, 5, 0,
+                        Qt::AlignRight | Qt::AlignVCenter);
+      guiLay->addWidget(m_rasterFormatOm, 5, 1, Qt::AlignLeft);
+      guiLay->addWidget(m_frameFormatBtn, 5, 2, 1, 2, Qt::AlignLeft);
+
       // Width - Height
-      guiLay->addWidget(m_widthLabel, 5, 0, Qt::AlignRight | Qt::AlignVCenter);
-      guiLay->addWidget(m_widthFld, 5, 1);
-      guiLay->addWidget(m_heightLabel, 5, 2, Qt::AlignRight | Qt::AlignVCenter);
-      guiLay->addWidget(m_heightFld, 5, 3);
+      guiLay->addWidget(m_widthLabel, 6, 0, Qt::AlignRight | Qt::AlignVCenter);
+      guiLay->addWidget(m_widthFld, 6, 1);
+      guiLay->addWidget(m_heightLabel, 6, 2, Qt::AlignRight | Qt::AlignVCenter);
+      guiLay->addWidget(m_heightFld, 6, 3);
 
       // DPI
-      guiLay->addWidget(m_dpiLabel, 6, 0, Qt::AlignRight | Qt::AlignVCenter);
-      guiLay->addWidget(m_dpiFld, 6, 1, 1, 3);
+      guiLay->addWidget(m_dpiLabel, 7, 0, Qt::AlignRight | Qt::AlignVCenter);
+      guiLay->addWidget(m_dpiFld, 7, 1);
     }
     guiLay->setColumnStretch(0, 0);
     guiLay->setColumnStretch(1, 0);
@@ -276,12 +295,15 @@ LevelCreatePopup::LevelCreatePopup()
   bool ret = true;
   ret      = ret && connect(m_levelTypeOm, SIGNAL(currentIndexChanged(int)),
                        SLOT(onLevelTypeChanged(int)));
+  ret      = ret && connect(m_frameFormatBtn, SIGNAL(clicked()), this,
+                       SLOT(onFrameFormatButton()));
   ret      = ret && connect(okBtn, SIGNAL(clicked()), this, SLOT(onOkBtn()));
   ret      = ret && connect(cancelBtn, SIGNAL(clicked()), this, SLOT(reject()));
   ret =
       ret && connect(applyBtn, SIGNAL(clicked()), this, SLOT(onApplyButton()));
 
   setSizeWidgetEnable(false);
+  setRasterWidgetVisible(false);
 }
 
 //-----------------------------------------------------------------------------
@@ -328,9 +350,16 @@ bool LevelCreatePopup::levelExists(std::wstring levelName) {
            .withParentDir(parentDir);
   actualFp = scene->decodeFilePath(fp);
 
-  if (levelSet->getLevel(levelName) != 0 ||
-      TSystem::doesExistFileOrLevel(actualFp)) {
+  if (TSystem::doesExistFileOrLevel(actualFp))
     return true;
+  else if (TXshLevel *level = levelSet->getLevel(levelName)) {
+    // even if the level exists in the scene cast, it can be replaced if it is
+    // unused
+    if (Preferences::instance()->isAutoRemoveUnusedLevelsEnabled() &&
+        !scene->getChildStack()->getTopXsheet()->isLevelUsed(level))
+      return false;
+    else
+      return true;
   } else
     return false;
 }
@@ -366,6 +395,15 @@ void LevelCreatePopup::setSizeWidgetEnable(bool isEnable) {
 
 //-----------------------------------------------------------------------------
 
+void LevelCreatePopup::setRasterWidgetVisible(bool isVisible) {
+  m_rasterFormatLabel->setVisible(isVisible);
+  m_rasterFormatOm->setVisible(isVisible);
+  m_frameFormatBtn->setVisible(isVisible);
+  updateGeometry();
+}
+
+//-----------------------------------------------------------------------------
+
 int LevelCreatePopup::getLevelType() const {
   return m_levelTypeOm->currentData().toInt();
 }
@@ -378,6 +416,9 @@ void LevelCreatePopup::onLevelTypeChanged(int index) {
     setSizeWidgetEnable(true);
   else
     setSizeWidgetEnable(false);
+
+  setRasterWidgetVisible(type == OVL_XSHLEVEL || type == TZI_XSHLEVEL);
+
   updatePath();
 
   std::wstring levelName = m_nameFld->text().toStdWString();
@@ -411,6 +452,17 @@ void LevelCreatePopup::onApplyButton() {
 
 //-----------------------------------------------------------------------------
 
+void LevelCreatePopup::onFrameFormatButton() {
+  // Tentatively use the preview output settings
+  ToonzScene *scene = TApp::instance()->getCurrentScene()->getScene();
+  if (!scene) return;
+  std::string ext = m_rasterFormatOm->currentData().toString().toStdString();
+  openFormatSettingsPopup(this, ext, nullptr,
+                          &scene->getProperties()->formatTemplateFIdForInput());
+}
+
+//-----------------------------------------------------------------------------
+
 bool LevelCreatePopup::apply() {
   TApp *app = TApp::instance();
   int row   = app->getCurrentFrame()->getFrame();
@@ -470,18 +522,27 @@ bool LevelCreatePopup::apply() {
 
   int numFrames = step * (((to - from) / inc) + 1);
 
-  if (scene->getLevelSet()->getLevel(levelName)) {
-    error(
-        tr("The level name specified is already used: please choose a "
-           "different level name"));
-    m_nameFld->selectAll();
-    return false;
+  TXshLevel *existingLevel = scene->getLevelSet()->getLevel(levelName);
+  if (existingLevel) {
+    // check if the existing level can be removed
+    if (!Preferences::instance()->isAutoRemoveUnusedLevelsEnabled() ||
+        scene->getChildStack()->getTopXsheet()->isLevelUsed(existingLevel)) {
+      error(
+          tr("The level name specified is already used: please choose a "
+             "different level name"));
+      m_nameFld->selectAll();
+      return false;
+    }
+    // if the exitingLevel is not null, it will be removed afterwards
   }
 
   TFilePath parentDir(m_pathFld->getPath().toStdWString());
   TFilePath fp =
       scene->getDefaultLevelPath(lType, levelName).withParentDir(parentDir);
 
+  if (lType == OVL_XSHLEVEL || lType == TZI_XSHLEVEL)
+    fp = fp.withType(m_rasterFormatOm->currentData().toString().toStdString());
+
   TFilePath actualFp = scene->decodeFilePath(fp);
   if (TSystem::doesExistFileOrLevel(actualFp)) {
     error(
@@ -509,6 +570,18 @@ bool LevelCreatePopup::apply() {
     }
   }
 
+  TUndoManager::manager()->beginBlock();
+
+  // existingLevel is not nullptr only if the level is unused AND
+  // the preference option AutoRemoveUnusedLevels is ON
+  if (existingLevel) {
+    bool ok = LevelCmd::removeLevelFromCast(existingLevel, scene, false);
+    assert(ok);
+    DVGui::info(QObject::tr("Removed unused level %1 from the scene cast. "
+                            "(This behavior can be disabled in Preferences.)")
+                    .arg(QString::fromStdWString(levelName)));
+  }
+
   /*-- これからLevelを配置しようとしているセルが空いているかどうかのチェック
    * --*/
   bool areColumnsShifted = false;
@@ -544,6 +617,7 @@ bool LevelCreatePopup::apply() {
   TXshLevel *level =
       scene->createNewLevel(lType, levelName, TDimension(), 0, fp);
   TXshSimpleLevel *sl = dynamic_cast<TXshSimpleLevel *>(level);
+
   assert(sl);
   sl->setPath(fp, true);
   if (lType == TZP_XSHLEVEL || lType == OVL_XSHLEVEL) {
@@ -555,7 +629,6 @@ bool LevelCreatePopup::apply() {
 
   for (i = from; i <= to; i += inc) {
     TFrameId fid(i);
-    TXshCell cell(sl, fid);
     if (lType == PLI_XSHLEVEL)
       sl->setFrame(fid, new TVectorImage());
     else if (lType == TZP_XSHLEVEL) {
@@ -570,8 +643,12 @@ bool LevelCreatePopup::apply() {
       raster->clear();
       TRasterImageP ri(raster);
       ri->setDpi(dpi, dpi);
+      // modify frameId to be with the same frame format as existing frames
+      TFrameId tmplFId = scene->getProperties()->formatTemplateFIdForInput();
+      sl->formatFId(fid, tmplFId);
       sl->setFrame(fid, ri);
     }
+    TXshCell cell(sl, fid);
     for (j = 0; j < step; j++) xsh->setCell(row++, col, cell);
   }
 
@@ -582,6 +659,8 @@ bool LevelCreatePopup::apply() {
 
   undo->onAdd(sl);
 
+  TUndoManager::manager()->endBlock();
+
   app->getCurrentScene()->notifySceneChanged();
   app->getCurrentScene()->notifyCastChange();
   app->getCurrentXsheet()->notifyXsheetChanged();
