@@ -365,7 +365,7 @@ int main(int argc, char *argv[]) {
   a.setAttribute(Qt::AA_UseDesktopOpenGL, true);
 #endif
 
-  // Some Qt objects are destroyed badly withouth a living qApp. So, we must
+  // Some Qt objects are destroyed badly without a living qApp. So, we must
   // enforce a way to either
   // postpone the application destruction until the very end, OR ensure that
   // sensible objects are
@@ -417,7 +417,7 @@ int main(int argc, char *argv[]) {
 
   // Set the app's locale for numeric stuff to standard C. This is important for
   // atof() and similar
-  // calls that are locale-dependant.
+  // calls that are locale-dependent.
   setlocale(LC_NUMERIC, "C");
 
 // Set current directory to the bundle/application path - this is needed to have
@@ -444,8 +444,7 @@ int main(int argc, char *argv[]) {
 
   // splash screen
   QPixmap splashPixmap = QIcon(":Resources/splash.svg").pixmap(QSize(610, 344));
-  splashPixmap.setDevicePixelRatio(QApplication::desktop()->devicePixelRatio());
-// QPixmap splashPixmap(":Resources/splash.png");
+
 #ifdef _WIN32
   QFont font("Segoe UI", -1);
 #else
@@ -490,6 +489,16 @@ int main(int argc, char *argv[]) {
   // Toonz environment
   initToonzEnv(argumentPathValues);
 
+  // prepare for 30bit display
+  if (Preferences::instance()->is30bitDisplayEnabled()) {
+    QSurfaceFormat sFmt = QSurfaceFormat::defaultFormat();
+    sFmt.setRedBufferSize(10);
+    sFmt.setGreenBufferSize(10);
+    sFmt.setBlueBufferSize(10);
+    sFmt.setAlphaBufferSize(2);
+    QSurfaceFormat::setDefaultFormat(sFmt);
+  }
+
   // Initialize thread components
   TThread::init();
 
@@ -726,7 +735,10 @@ int main(int argc, char *argv[]) {
 
   TFilePath fp = ToonzFolder::getModuleFile("mainwindow.ini");
   QSettings settings(toQString(fp), QSettings::IniFormat);
-  w.restoreGeometry(settings.value("MainWindowGeometry").toByteArray());
+  if (settings.contains("MainWindowGeometry"))
+    w.restoreGeometry(settings.value("MainWindowGeometry").toByteArray());
+  else  // maximize window on the first launch
+    w.setWindowState(w.windowState() | Qt::WindowMaximized);
 
   ExpressionReferenceManager::instance()->init();
 
