@@ -412,6 +412,7 @@
 #define MI_PencilTest "MI_PencilTest"
 #define MI_AudioRecording "MI_AudioRecording"
 #define MI_LipSyncPopup "MI_LipSyncPopup"
+#define MI_AutoLipSyncPopup "MI_AutoLipSyncPopup"
 #define MI_AutoInputCellNumber "MI_AutoInputCellNumber"
 #define MI_TouchGestureControl "MI_TouchGestureControl"
 #define MI_SeparateColors "MI_SeparateColors"
@@ -453,4 +454,13 @@
 #define MI_FlipPrevGuideStroke "MI_FlipPrevGuideStroke"
 
 #define MI_ExportXDTS "MI_ExportXDTS"
+#define MI_ExportTvpJson "MI_ExportTvpJson"
+#define MI_ExportXsheetPDF "MI_ExportXsheetPDF"
+
+// mark id is added for each actual command (i.g. MI_SetCellMark1)
+#define MI_SetCellMark "MI_SetCellMark"
+
+#define MI_ZoomInAndFitPanel "MI_ZoomInAndFitPanel"
+#define MI_ZoomOutAndFitPanel "MI_ZoomOutAndFitPanel"
+
 #endif
