@@ -261,10 +261,12 @@ void SceneViewerPanel::onShowHideActionTriggered(QAction *act) {
   updateShowHide();
 }
 
-void SceneViewerPanel::onDrawFrame(
-    int frame, const ImagePainter::VisualSettings &settings) {
+void SceneViewerPanel::onDrawFrame(int frame,
+                                   const ImagePainter::VisualSettings &settings,
+                                   QElapsedTimer *, qint64) {
   TApp *app = TApp::instance();
   m_sceneViewer->setVisual(settings);
+
   TFrameHandle *frameHandle = app->getCurrentFrame();
 
   if (m_sceneViewer->isPreviewEnabled()) {
