@@ -24,6 +24,24 @@
 #include "tproperty.h"
 #include "tiio.h"
 
+namespace {
+const QList<TSceneProperties::CellMark> getDefaultCellMarks() {
+  return QList<TSceneProperties::CellMark>{
+      {QObject::tr("Red"), TPixel32(167, 55, 55)},
+      {QObject::tr("Orange"), TPixel32(195, 115, 40)},
+      {QObject::tr("Yellow"), TPixel32(214, 183, 22)},
+      {QObject::tr("Light Green"), TPixel32(165, 179, 57)},
+      {QObject::tr("Green"), TPixel32(82, 157, 79)},
+      {QObject::tr("Light Blue"), TPixel32(71, 142, 165)},
+      {QObject::tr("Blue"), TPixel32(64, 103, 172)},
+      {QObject::tr("Dark Blue"), TPixel32(60, 49, 187)},
+      {QObject::tr("Purple"), TPixel32(108, 66, 170)},
+      {QObject::tr("Pink"), TPixel32(161, 75, 140)},
+      {QObject::tr("Dark Pink"), TPixel32(111, 29, 108)},
+      {QObject::tr("White"), TPixel32(255, 255, 255)}};
+}
+}  // namespace
+
 //=============================================================================
 
 TSceneProperties::TSceneProperties()
@@ -50,6 +68,9 @@ TSceneProperties::TSceneProperties()
   m_notesColor.push_back(TPixel32(145, 240, 145));
   m_notesColor.push_back(TPixel32(130, 255, 210));
   m_notesColor.push_back(TPixel32(150, 245, 255));
+
+  // Default Cell Marks
+  m_cellMarks = getDefaultCellMarks();
 }
 
 //-----------------------------------------------------------------------------
@@ -82,7 +103,7 @@ void TSceneProperties::assign(const TSceneProperties *sprop) {
 
   if (sprop != this) {
     m_cameras = sprop->m_cameras;
-    for (int i     = 0; i < (int)m_cameras.size(); i++)
+    for (int i = 0; i < (int)m_cameras.size(); i++)
       m_cameras[i] = new TCamera(*m_cameras[i]);
   }
   m_bgColor                   = sprop->m_bgColor;
@@ -149,7 +170,7 @@ void TSceneProperties::setFieldGuideSize(int size) {
 
 void TSceneProperties::setFieldGuideAspectRatio(double ar) {
   assert(ar >= 0);
-  if (ar <= 0) ar         = 1;
+  if (ar <= 0) ar = 1;
   m_fieldGuideAspectRatio = ar;
 }
 
@@ -203,8 +224,8 @@ void TSceneProperties::saveData(TOStream &os) const {
     os.child("threadsIndex") << out.getThreadIndex();
     os.child("maxTileSizeIndex") << out.getMaxTileSizeIndex();
     os.child("subcameraPrev") << (out.isSubcameraPreview() ? 1 : 0);
-    os.child("stereoscopic") << (rs.m_stereoscopic ? 1 : 0)
-                             << rs.m_stereoscopicShift;
+    os.child("stereoscopic")
+        << (rs.m_stereoscopic ? 1 : 0) << rs.m_stereoscopicShift;
 
     switch (rs.m_quality) {
     case TRenderSettings::StandardResampleQuality:
@@ -300,6 +321,16 @@ void TSceneProperties::saveData(TOStream &os) const {
       os.closeChild();
     }
 
+    if (out.formatTemplateFId().getZeroPadding() !=
+            TFrameId().getZeroPadding() ||
+        out.formatTemplateFId().getStartSeqInd() !=
+            TFrameId().getStartSeqInd()) {
+      os.openChild("frameFormat");
+      os.child("padding") << (int)out.formatTemplateFId().getZeroPadding();
+      os.child("sepchar") << QString(out.formatTemplateFId().getStartSeqInd());
+      os.closeChild();
+    }
+
     os.closeChild();  // </output>
   }
   os.closeChild();
@@ -323,6 +354,12 @@ void TSceneProperties::saveData(TOStream &os) const {
   os.openChild("noteColors");
   for (i = 0; i < m_notesColor.size(); i++) os << m_notesColor.at(i);
   os.closeChild();
+
+  if (!hasDefaultCellMarks()) {
+    os.openChild("cellMarks");
+    for (auto mark : m_cellMarks) os << mark.name.toStdString() << mark.color;
+    os.closeChild();
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -423,7 +460,7 @@ void TSceneProperties::loadData(TIStream &is, bool isLoadingProject) {
           if (name == "preview")
             outPtr = m_previewProp;
           else if (name == "main")
-            outPtr               = m_outputProp;
+            outPtr = m_outputProp;
           TOutputProperties &out = *outPtr;
           TRenderSettings renderSettings;
           if (globFrom != -1)
@@ -664,6 +701,20 @@ void TSceneProperties::loadData(TIStream &is, bool isLoadingProject) {
             } else if (tagName == "clapperboardSettings") {
               assert(out.getBoardSettings());
               out.getBoardSettings()->loadData(is);
+            } else if (tagName == "frameFormat") {
+              while (is.matchTag(tagName)) {
+                if (tagName == "padding") {
+                  int padding;
+                  is >> padding;
+                  out.formatTemplateFId().setZeroPadding(padding);
+                } else if (tagName == "sepchar") {
+                  QString sepChar;
+                  is >> sepChar;
+                  out.formatTemplateFId().setStartSeqInd(sepChar[0].toLatin1());
+                } else
+                  throw TException("unexpected tag: " + tagName);
+                is.closeChild();
+              }  // end while
             } else {
               throw TException("unexpected property tag: " + tagName);
             }
@@ -707,6 +758,15 @@ void TSceneProperties::loadData(TIStream &is, bool isLoadingProject) {
       assert(i == 7);
     } else if (tagName == "cameraCaputureSaveInPath") {
       is >> m_camCapSaveInPath;
+    } else if (tagName == "cellMarks") {
+      int i = 0;
+      while (!is.eos()) {
+        TPixel32 color;
+        std::string name;
+        is >> name >> color;
+        m_cellMarks.replace(i, {QString::fromStdString(name), color});
+        i++;
+      }
     } else {
       throw TException("unexpected property tag: " + tagName);
     }
@@ -780,3 +840,36 @@ TPixel32 TSceneProperties::getNoteColor(int colorIndex) const {
 void TSceneProperties::setNoteColor(TPixel32 color, int colorIndex) {
   m_notesColor[colorIndex] = color;
 }
+
+//-----------------------------------------------------------------------------
+
+QList<TSceneProperties::CellMark> TSceneProperties::getCellMarks() const {
+  return m_cellMarks;
+}
+
+//-----------------------------------------------------------------------------
+
+TSceneProperties::CellMark TSceneProperties::getCellMark(int index) const {
+  return m_cellMarks[index];
+}
+
+//-----------------------------------------------------------------------------
+
+void TSceneProperties::setCellMark(const TSceneProperties::CellMark &mark,
+                                   int index) {
+  m_cellMarks[index] = mark;
+}
+
+//-----------------------------------------------------------------------------
+// check if the cell mark settings are modified
+bool TSceneProperties::hasDefaultCellMarks() const {
+  if (m_cellMarks.size() != 12) return false;
+  return m_cellMarks == getDefaultCellMarks();
+}
+
+//-----------------------------------------------------------------------------
+// templateFId in preview settings is used for "input" file format
+// such as new raster level, captured images by camera capture feature, etc.
+TFrameId &TSceneProperties::formatTemplateFIdForInput() {
+  return m_previewProp->formatTemplateFId();
+}
