@@ -9,6 +9,7 @@
 #include "toonz/observer.h"
 #include "toonz/toonzfolders.h"
 #include "toonz/cleanupparameters.h"
+#include "toonz/filepathproperties.h"
 
 // TnzBase includes
 #include "tenv.h"
@@ -16,6 +17,7 @@
 // TnzCore includes
 #include "tsystem.h"
 #include "tstream.h"
+#include "tfilepath.h"
 #include "tfilepath_io.h"
 #include "tconvert.h"
 
@@ -285,11 +287,18 @@ void hideOlderProjectFiles(const TFilePath &folderPath) {
         \see TProjectManager and TOStream.
   */
 
-TProject::TProject() : m_name(), m_path(), m_sprop(new TSceneProperties()) {}
+TProject::TProject()
+    : m_name()
+    , m_path()
+    , m_sprop(new TSceneProperties())
+    , m_fpProp(new FilePathProperties()) {}
 
 //-------------------------------------------------------------------
 
-TProject::~TProject() { delete m_sprop; }
+TProject::~TProject() {
+  delete m_sprop;
+  delete m_fpProp;
+}
 
 //-------------------------------------------------------------------
 /*! Associates the \b name to the specified \b path.
@@ -569,6 +578,13 @@ bool TProject::save(const TFilePath &projectPath) {
   os.openChild("sceneProperties");
   getSceneProperties().saveData(os);
   os.closeChild();
+
+  if (!getFilePathProperties()->isDefault()) {
+    os.openChild("filePathProperties");
+    getFilePathProperties()->saveData(os);
+    os.closeChild();
+  }
+
   os.closeChild();
 
   // crea (se necessario) le directory relative ai vari folder
@@ -674,6 +690,9 @@ void TProject::load(const TFilePath &projectPath) {
       }
       setSceneProperties(sprop);
       is.matchEndTag();
+    } else if (tagName == "filePathProperties") {
+      m_fpProp->loadData(is);
+      is.matchEndTag();
     }
   }
 }
@@ -725,7 +744,7 @@ public:
 
         It is possible to handle more than one project root.
         The class maintains a container this purpose. All the projects roots
-   must be set by hand in the windows registery. By default, only one project
+   must be set by hand in the windows registry. By default, only one project
    root is created when toonz is installed.\n The project root container can be
    updated using addProjectsRoot(const TFilePath &root),
    addDefaultProjectsRoot() methods.
@@ -977,6 +996,12 @@ TProjectP TProjectManager::getCurrentProject() {
     assert(TProject::isAProjectPath(fp));
     currentProject = new TProject();
     currentProject->load(fp);
+
+    // update TFilePath condition on loading the current project
+    FilePathProperties *fpProp = currentProject->getFilePathProperties();
+    TFilePath::setFilePathProperties(fpProp->useStandard(),
+                                     fpProp->acceptNonAlphabetSuffix(),
+                                     fpProp->letterCountForSuffix());
   }
   return currentProject;
 }
