@@ -22,6 +22,8 @@
 
 #include "../toonz/tapp.h"
 
+#include <time.h>
+
 // Qt includes
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -153,110 +155,107 @@ void PlaybackExecutor::resetFps(int fps) { m_fps = fps; }
 void PlaybackExecutor::run() {
   // (Daniele)
   // We'll build the fps considering an interval of roughly 1 second (the last
-  // one).
-  // However, the fps should be sampled at a faster rate. Each sample is taken
-  // at
-  // 1/4 second, and the last 4 samples data are stored to keep trace of the
-  // last
-  // second of playback.
+  // one). However, the fps should be sampled at a faster rate. Each sample is
+  // taken at 1/4 second, and the last 4 samples data are stored to keep trace
+  // of the last second of playback.
+  m_timer.start();
 
-  TStopWatch timer;
-  timer.start();
-
-  TUINT32 timeResolution =
-      250;  // Use a sufficient sampling resolution (currently 1/4 sec).
-            // Fps calculation is made once per sample.
+  qint64 timeResolution =
+      250 * 1000000;  // Use a sufficient sampling resolution (currently 1/4
+                      // sec). Fps calculation is made once per sample.
 
   int fps = m_fps, currSample = 0;
-  TUINT32 playedFramesCount = 0;
-  TUINT32 loadedInstant, nextSampleInstant = timeResolution;
-  TUINT32 sampleTotalLoadingTime = 0;
+  qint64 playedFramesCount = 0;
+  qint64 nextSampleInstant = timeResolution;
 
-  TUINT32 lastFrameCounts[4]    = {0, 0, 0,
-                                0};  // Keep the last 4 'played frames' counts.
-  TUINT32 lastSampleInstants[4] = {0, 0, 0,
-                                   0};  // Same for the last sampling instants
-  TUINT32 lastLoadingTimes[4]   = {0, 0, 0,
-                                 0};  // Same for total sample loading times
+  qint64 lastFrameCounts[4]    = {0, 0, 0,
+                               0};  // Keep the last 4 'played frames' counts.
+  qint64 lastSampleInstants[4] = {0, 0, 0,
+                                  0};  // Same for the last sampling instants
 
-  double targetFrameTime =
-      1000.0 / abs(m_fps);  // User-required time between frames
+  qint64 targetFrameTime =
+      1000000000 / (qint64)abs(m_fps);  // User-required time between frames
 
-  TUINT32 emissionInstant = 0;  // Effective instant in which loading is invoked
-  double emissionInstantD = 0.0;  // Double precision version of the above
-
-  double lastLoadingTime = 0.0;  // Mean frame loading time in the last sample
+  qint64 emissionInstant = 0;  // starting instant in which rendering is invoked
+  qint64 avgSwapTime     = 0;  // average time for swapping buffers
+  qint64 shortTermDelayAdjuster =
+      0;  // accumurate recent errors and adjust in short term
 
   while (!m_abort) {
-    emissionInstant = timer.getTotalTime();
+    emissionInstant = m_timer.nsecsElapsed();
 
-    // Draw the next frame
-    if (playedFramesCount)
-      emit nextFrame(fps);  // Show the next frame, telling
-                            // currently measured fps
+    if (emissionInstant > nextSampleInstant) {
+      // Fps calculation
+      qint64 framesCount = playedFramesCount - lastFrameCounts[currSample];
+      qint64 elapsedTime = emissionInstant - lastSampleInstants[currSample];
+      fps                = troundp((long double)(1000000000 * framesCount) /
+                    (long double)elapsedTime);
 
-    if (FlipConsole::m_areLinked) {
-      // In case there are linked consoles, update them too.
-      // Their load time must be included in the fps calculation.
-      int i, consolesCount = FlipConsole::m_visibleConsoles.size();
-      for (i = 0; i < consolesCount; ++i) {
-        FlipConsole *console = FlipConsole::m_visibleConsoles.at(i);
-        if (console->isLinkable() && console != FlipConsole::m_currentConsole)
-          console->playbackExecutor().emitNextFrame(m_fps < 0 ? -fps : fps);
+      targetFrameTime =
+          1000000000 / (qint64)abs(m_fps);  // m_fps could have changed...
+
+      // estimate time for swapping buffers
+      qint64 avgSwapTimeD = (elapsedTime / framesCount) - targetFrameTime;
+      if (avgSwapTime - avgSwapTimeD >
+          20000000)  // Reset beyond, say, 20 msecs tolerance.
+        avgSwapTime = avgSwapTimeD;
+      else
+        avgSwapTime += avgSwapTimeD;
+      avgSwapTime = std::min(targetFrameTime, std::max(avgSwapTime, (qint64)0));
+
+      // prepare for the next sampling
+      lastFrameCounts[currSample]    = playedFramesCount;
+      lastSampleInstants[currSample] = emissionInstant;
+      currSample                     = (currSample + 1) % 4;
+      nextSampleInstant              = emissionInstant + timeResolution;
+    }
+
+    // draw the next frame
+    if (playedFramesCount) {
+      qint64 delayAdjust = shortTermDelayAdjuster / 4;
+      qint64 targetInstant =
+          emissionInstant + targetFrameTime - avgSwapTime - delayAdjust;
+      targetInstant = std::max(targetInstant, emissionInstant);
+      shortTermDelayAdjuster -= delayAdjust;
+
+      // Show the next frame, telling currently measured fps
+      // For the Flipbook, the wait time will be inserted at the end of paintGL
+      // in order to achieve precise playback
+      emit nextFrame(fps, &m_timer, targetInstant);
+
+      // Playing on Viewer / Combo Viewer will advance the current frame.
+      // Calling qApp->processEvents() on drawing frame causes repaint of other
+      // panels which slows playback. Therefore in Viewer / Combo Viewer panels
+      // it just calls update() and necessary wait will be inserted here.
+      qint64 currentInstant = m_timer.nsecsElapsed();
+      while (currentInstant < targetInstant) {
+        currentInstant = m_timer.nsecsElapsed();
+      }
+
+      if (FlipConsole::m_areLinked) {
+        // In case there are linked consoles, update them too.
+        // Their load time must be included in the fps calculation.
+        int i, consolesCount = FlipConsole::m_visibleConsoles.size();
+        for (i = 0; i < consolesCount; ++i) {
+          FlipConsole *console = FlipConsole::m_visibleConsoles.at(i);
+          if (console->isLinkable() && console != FlipConsole::m_currentConsole)
+            console->playbackExecutor().emitNextFrame(m_fps < 0 ? -fps : fps);
+        }
       }
     }
 
     //-------- Each nextFrame() blocks until the frame has been shown ---------
 
+    // accumurate error and slightly adjust waiting time for subsequent frames
+    qint64 delay = m_timer.nsecsElapsed() - emissionInstant - targetFrameTime;
+    // just ignore a large error
+    if (delay < targetFrameTime) shortTermDelayAdjuster += delay;
+
     ++playedFramesCount;
-    loadedInstant = timer.getTotalTime();
-    sampleTotalLoadingTime += (loadedInstant - emissionInstant);
-
-    // Recalculate data only after the specified time resolution has passed.
-    if (loadedInstant > nextSampleInstant) {
-      // Sampling instant. Perform calculations.
-
-      // Store values
-      TUINT32 framesCount = playedFramesCount - lastFrameCounts[currSample];
-      TUINT32 elapsedTime = loadedInstant - lastSampleInstants[currSample];
-      double loadingTime =
-          (sampleTotalLoadingTime - lastLoadingTimes[currSample]) /
-          (double)framesCount;
-
-      lastFrameCounts[currSample]    = playedFramesCount;
-      lastSampleInstants[currSample] = loadedInstant;
-      lastLoadingTimes[currSample]   = sampleTotalLoadingTime;
-
-      currSample        = (currSample + 1) % 4;
-      nextSampleInstant = loadedInstant + timeResolution;
-
-      // Rebuild current fps
-      fps             = troundp((1000 * framesCount) / (double)elapsedTime);
-      targetFrameTime = 1000.0 / abs(m_fps);  // m_fps could have changed...
-
-      // In case the playback is too slow to keep the required pace, reset the
-      // emission timeline.
-      // Otherwise, it should be kept as the difference needs to be compensated
-      // to get the required fps.
-      if ((int)emissionInstant - (int)emissionInstantD >
-          20)  // Reset beyond, say, 20 msecs tolerance.
-        emissionInstantD = (double)loadedInstant - loadingTime;
-      else
-        emissionInstantD +=
-            lastLoadingTime -
-            loadingTime;  // Otherwise, just adapt to the new loading time
-
-      lastLoadingTime = loadingTime;
-    }
-
-    // Calculate the new emission instant
-    emissionInstant = std::max((int)(emissionInstantD += targetFrameTime), 0);
-
-    // Sleep until the next emission instant has been reached
-    while (timer.getTotalTime() < emissionInstant) msleep(1);
   }
 
   m_abort = false;
+  m_timer.invalidate();
 }
 
 //==========================================================================================
@@ -530,8 +529,10 @@ FlipConsole::FlipConsole(QVBoxLayout *mainLayout, std::vector<int> gadgetsMask,
 
   applyCustomizeMask();
 
-  bool ret = connect(&m_playbackExecutor, SIGNAL(nextFrame(int)), this,
-                     SLOT(onNextFrame(int)), Qt::BlockingQueuedConnection);
+  bool ret = connect(&m_playbackExecutor,
+                     SIGNAL(nextFrame(int, QElapsedTimer *, qint64)), this,
+                     SLOT(onNextFrame(int, QElapsedTimer *, qint64)),
+                     Qt::BlockingQueuedConnection);
 
   assert(ret);
 
@@ -765,7 +766,8 @@ void FlipConsole::toggleLinked() {
 
 //----------------------------------------------------------------------------
 
-bool FlipConsole::drawBlanks(int from, int to) {
+bool FlipConsole::drawBlanks(int from, int to, QElapsedTimer *timer,
+                             qint64 target) {
   if (m_blanksCount == 0 || m_isPlay || m_framesCount <= 1) return false;
 
   // enable blanks only when the blank button is pressed
@@ -781,7 +783,7 @@ bool FlipConsole::drawBlanks(int from, int to) {
     m_blanksToDraw = (m_blanksToDraw == 0 ? m_blanksCount : m_blanksToDraw - 1);
     m_settings.m_blankColor     = m_blankColor;
     m_settings.m_drawBlankFrame = true;
-    m_consoleOwner->onDrawFrame(from, m_settings);
+    m_consoleOwner->onDrawFrame(from, m_settings, timer, target);
     m_settings.m_drawBlankFrame = false;
     return true;
   }
@@ -792,17 +794,19 @@ bool FlipConsole::drawBlanks(int from, int to) {
 
 //----------------------------------------------------------------------------
 
-void FlipConsole::onNextFrame(int fps) {
+void FlipConsole::onNextFrame(int fps, QElapsedTimer *timer,
+                              qint64 targetInstant) {
+  if (playbackExecutor().isAborted()) return;
   if (fps < 0)  // can be negative only if is a linked console; it means that
                 // the master console is playing backward
   {
     bool reverse = m_reverse;
     m_reverse    = true;
     fps          = -fps;
-    playNextFrame();
+    playNextFrame(timer, targetInstant);
     m_reverse = reverse;
   } else
-    playNextFrame();
+    playNextFrame(timer, targetInstant);
 
   if (fps == -1) return;
   if (m_fpsLabel)
@@ -818,7 +822,7 @@ void FlipConsole::onNextFrame(int fps) {
 
 //----------------------------------------------------------------------------
 
-void FlipConsole::playNextFrame() {
+void FlipConsole::playNextFrame(QElapsedTimer *timer, qint64 targetInstant) {
   int from = m_from, to = m_to;
   if (m_markerFrom <= m_markerTo) from = m_markerFrom, to = m_markerTo;
 
@@ -831,7 +835,7 @@ void FlipConsole::playNextFrame() {
       m_currentFrame = (m_reverse ? to : from);
     emit playStateChanged(false);
   } else {
-    if (drawBlanks(from, to)) return;
+    if (drawBlanks(from, to, timer, targetInstant)) return;
 
     if (m_reverse)
       m_currentFrame =
@@ -845,7 +849,7 @@ void FlipConsole::playNextFrame() {
   m_editCurrFrame->setText(QString::number(m_currentFrame));
   m_settings.m_blankColor        = TPixel::Transparent;
   m_settings.m_recomputeIfNeeded = true;
-  m_consoleOwner->onDrawFrame(m_currentFrame, m_settings);
+  m_consoleOwner->onDrawFrame(m_currentFrame, m_settings, timer, targetInstant);
 }
 
 //-----------------------------------------------------------------------------
@@ -1361,7 +1365,7 @@ void FlipConsole::enableBlanks(bool state) {
 }
 
 //-----------------------------------------------------------------------------
-/*! call consoleOwner->onDrawFrame() intead of emitting drawFrame signal
+/*! call consoleOwner->onDrawFrame() instead of emitting drawFrame signal
  */
 void FlipConsole::showCurrentFrame() {
   m_consoleOwner->onDrawFrame(m_currentFrame, m_settings);
