@@ -520,9 +520,9 @@ QPainterPath FunctionPanel::getSegmentPainterPath(TDoubleParam *curve,
 //-----------------------------------------------------------------------------
 
 void FunctionPanel::drawCurrentFrame(QPainter &painter) {
-  int currentframe                = 0;
+  int currentframe = 0;
   if (m_frameHandle) currentframe = m_frameHandle->getFrame();
-  int x                           = frameToX(currentframe);
+  int x = frameToX(currentframe);
   if (m_currentFrameStatus == 0)
     painter.setPen(Qt::magenta);
   else if (m_currentFrameStatus == 1)
@@ -863,8 +863,9 @@ void FunctionPanel::updateGadgets(TDoubleParam *curve) {
     //       So, keyframe data could be shared, but adjacent segment lengths
     //       could not...
 
-    if (it != iLast && (kf.m_type == TDoubleKeyframe::SpeedInOut ||
-                        kf.m_type == TDoubleKeyframe::EaseInOut) &&
+    if (it != iLast &&
+        (kf.m_type == TDoubleKeyframe::SpeedInOut ||
+         kf.m_type == TDoubleKeyframe::EaseInOut) &&
         kf.m_speedOut.x != 0) {
       QPointF p(frameToX(frame + kf.m_speedOut.x), groupHandleY);
       Gadget gadget((FunctionPanel::Handle)101, -1, p, 6, 15);  // type value...
@@ -993,11 +994,6 @@ void FunctionPanel::drawCurrentCurve(QPainter &painter) {
                        p.y() + easeHeight + easeTick);
       break;
 
-      painter.setBrush(
-          Qt::NoBrush);  // isSelected ? QColor(255,126,0) : Qt::white);
-      painter.setPen(isHighlighted ? QColor(255, 126, 0) : m_selectedColor);
-      painter.drawLine(p.x(), p.y() - 15, p.x(), p.y() + 15);
-      break;
     default:
       break;
     }
@@ -1146,8 +1142,8 @@ void FunctionPanel::paintEvent(QPaintEvent *e) {
     if (currentCurve) {
       const TUnit *unit = 0;
       if (currentCurve->getMeasure())
-        unit                 = currentCurve->getMeasure()->getCurrentUnit();
-      double displayValue    = m_cursor.value;
+        unit = currentCurve->getMeasure()->getCurrentUnit();
+      double displayValue = m_cursor.value;
       if (unit) displayValue = unit->convertTo(displayValue);
       // painter.setClipRect(0,oy0,height(),height()-oy0);
       int y = valueToY(currentCurve, m_cursor.value);
@@ -1180,9 +1176,13 @@ void FunctionPanel::paintEvent(QPaintEvent *e) {
 void FunctionPanel::mousePressEvent(QMouseEvent *e) {
   m_cursor.visible = false;
 
-  // m_dragTool should be 0. just in case...
-  assert(m_dragTool == 0);
-  m_dragTool = 0;
+  // m_dragTool can be non-zero when both the left and the mid buttons are
+  // pressed
+  if (m_dragTool) {
+    m_dragTool->release(e);
+    delete m_dragTool;
+    m_dragTool = nullptr;
+  }
 
   if (e->button() == Qt::MidButton) {
     // mid mouse click => panning
@@ -1237,7 +1237,7 @@ void FunctionPanel::mousePressEvent(QMouseEvent *e) {
       m_functionTreeModel ? m_functionTreeModel->getCurrentChannel() : 0;
   if (!currentChannel ||
       (getCurveDistance(currentChannel->getParam(), winPos) > maxDistance &&
-          closestGadgetId < 0)) {
+       closestGadgetId < 0)) {
     // if current channel is undefined or its curve is too far from the clicked
     // point
     // the user is possibly trying to select a different curve
@@ -1348,9 +1348,11 @@ int kIndex = dragTool->createKeyframe(frame);
 //-----------------------------------------------------------------------------
 
 void FunctionPanel::mouseReleaseEvent(QMouseEvent *e) {
-  if (m_dragTool) m_dragTool->release(e);
-  delete m_dragTool;
-  m_dragTool           = 0;
+  if (m_dragTool) {
+    m_dragTool->release(e);
+    delete m_dragTool;
+    m_dragTool = nullptr;
+  }
   m_cursor.visible     = true;
   m_currentFrameStatus = 0;
   update();
@@ -1454,11 +1456,11 @@ void FunctionPanel::fitGraphToWindow(bool currentCurveOnly) {
     TDoubleParam *curve = channel->getParam();
     if (currentCurveOnly && curve != getCurrentCurve()) continue;
 
-    const TUnit *unit             = 0;
+    const TUnit *unit = 0;
     if (curve->getMeasure()) unit = curve->getMeasure()->getCurrentUnit();
-    int n                         = curve->getKeyframeCount();
+    int n = curve->getKeyframeCount();
     if (n == 0) {
-      double v    = curve->getDefaultValue();
+      double v = curve->getDefaultValue();
       if (unit) v = unit->convertTo(v);
       if (v0 > v1)
         v0 = v1 = v;
@@ -1478,16 +1480,16 @@ void FunctionPanel::fitGraphToWindow(bool currentCurveOnly) {
         f0 = std::min(f0, fa);
         f1 = std::max(f1, fb);
       }
-      double v        = curve->getValue(fa);
-      if (unit) v     = unit->convertTo(v);
+      double v = curve->getValue(fa);
+      if (unit) v = unit->convertTo(v);
       if (v0 > v1) v0 = v1 = v;
-      int m                = 50;
+      int m = 50;
       for (int j = 0; j < m; j++) {
-        double t    = (double)j / (double)(m - 1);
-        double v    = curve->getValue((1 - t) * fa + t * fb);
+        double t = (double)j / (double)(m - 1);
+        double v = curve->getValue((1 - t) * fa + t * fb);
         if (unit) v = unit->convertTo(v);
-        v0          = std::min(v0, v);
-        v1          = std::max(v1, v);
+        v0 = std::min(v0, v);
+        v1 = std::max(v1, v);
       }
     }
   }
