@@ -6,7 +6,7 @@
 #include "tfilepath_io.h"
 #include "tfunctorinvoker.h"
 
-// TnzBase incudes
+// TnzBase includes
 #include "tunit.h"
 #include "tparamcontainer.h"
 #include "tparamset.h"
@@ -680,8 +680,12 @@ void FunctionTreeModel::Channel::setParam(const TParamP &param) {
 /*! in order to show the expression name in the tooltip
  */
 QString FunctionTreeModel::Channel::getExprRefName() const {
-  QString tmpName = QString(QString::fromStdWString(
-      TStringTable::translate(m_paramNamePref + m_param->getName())));
+  QString tmpName;
+  if (m_param->hasUILabel())
+    tmpName = QString::fromStdString(m_param->getUILabel());
+  else
+    tmpName = QString::fromStdWString(
+        TStringTable::translate(m_paramNamePref + m_param->getName()));
   /*--- stage
    * objectパラメータの場合、TableにあわせてtmpNameを代表的なExpression名にする---*/
   StageObjectChannelGroup *stageGroup =
