@@ -43,6 +43,8 @@
 
 #include <QDesktopServices>
 #include <QUrl>
+#include <QGuiApplication>
+#include <QScreen>
 
 using namespace DVGui;
 
@@ -151,7 +153,7 @@ void ParamsPage::setPageField(TIStream &is, const TFxP &fx, bool isVertical) {
     if (tagName == "control") {
       /*--- 設定ファイルからインタフェースの桁数を決める (PairSliderのみ実装。)
        * ---*/
-      int decimals            = 0;
+      int decimals            = -1;
       std::string decimalsStr = is.getTagAttribute("decimals");
       if (decimalsStr != "") {
         decimals = QString::fromStdString(decimalsStr).toInt();
@@ -168,7 +170,7 @@ void ParamsPage::setPageField(TIStream &is, const TFxP &fx, bool isVertical) {
             QString::fromStdWString(TStringTable::translate(paramName));
         ParamField *field = ParamField::create(this, str, param);
         if (field) {
-          if (decimals) field->setPrecision(decimals);
+          if (decimals >= 0) field->setPrecision(decimals);
           m_fields.push_back(field);
           /*-- hboxタグに挟まれているとき --*/
           if (isVertical == false) {
@@ -249,7 +251,6 @@ void ParamsPage::setPageField(TIStream &is, const TFxP &fx, bool isVertical) {
       if (shrinkStr != "" || modeSensitiveStr != "") {
         QWidget *tmpWidget;
         if (shrinkStr != "") {
-          tmpWidget           = new QWidget(this);
           shrink              = QString::fromStdString(shrinkStr).toInt();
           std::string label   = is.getTagAttribute("label");
           QCheckBox *checkBox = new QCheckBox(this);
@@ -262,9 +263,7 @@ void ParamsPage::setPageField(TIStream &is, const TFxP &fx, bool isVertical) {
           int currentRow = m_mainLayout->rowCount();
           m_mainLayout->addLayout(sepLay, currentRow, 0, 1, 2);
           m_mainLayout->setRowStretch(currentRow, 0);
-          //--- signal-slot connection
-          connect(checkBox, SIGNAL(toggled(bool)), tmpWidget,
-                  SLOT(setVisible(bool)));
+          tmpWidget = new ModeSensitiveBox(this, checkBox);
           checkBox->setChecked(shrink == 1);
           tmpWidget->setVisible(shrink == 1);
         } else {  // modeSensitiveStr != ""
@@ -421,7 +420,7 @@ void ParamsPage::setPageField(TIStream &is, const TFxP &fx, bool isVertical) {
           throw TException("unexpected tag " + tagName);
       }
       /*-- 表示コントロールをconnect --*/
-      if (controller_bpf) {
+      if (controller_bpf && (!on_items.isEmpty() || !off_items.isEmpty())) {
         /*-- ラベルとWidgetを両方表示/非表示 --*/
         for (int i = 0; i < on_items.size(); i++) {
           connect(controller_bpf, SIGNAL(toggled(bool)), on_items[i],
@@ -433,6 +432,8 @@ void ParamsPage::setPageField(TIStream &is, const TFxP &fx, bool isVertical) {
                   SLOT(setHidden(bool)));
           off_items[i]->show();
         }
+        connect(controller_bpf, SIGNAL(toggled(bool)), this,
+                SIGNAL(preferredPageSizeChanged()));
       } else
         std::cout << "controller_bpf NOT found!" << std::endl;
     } else
@@ -444,15 +445,49 @@ void ParamsPage::setPageField(TIStream &is, const TFxP &fx, bool isVertical) {
   }
 }
 
+//-----------------------------------------------------------------------------
+// add a slider for global control
+void ParamsPage::addGlobalControl(const TFxP &fx) {
+  if (!fx->getAttributes()->hasGlobalControl()) return;
+
+  std::string name = "globalIntensity";
+
+  TParamP param = fx->getParams()->getParam(name);
+  if (!param) return;
+
+  assert(param->hasUILabel());
+  QString str       = QString::fromStdString(param->getUILabel());
+  ParamField *field = ParamField::create(this, str, param);
+  if (!field) return;
+
+  int currentRow = m_mainLayout->rowCount();
+  if (!m_fields.isEmpty()) {
+    Separator *sep = new Separator("", this);
+    m_mainLayout->addWidget(sep, currentRow, 0, 1, 2);
+    m_mainLayout->setRowStretch(currentRow, 0);
+    currentRow = m_mainLayout->rowCount();
+  }
+
+  m_fields.push_back(field);
+  QLabel *label = new QLabel(str, this);
+  label->setObjectName("FxSettingsLabel");
+  m_mainLayout->addWidget(label, currentRow, 0,
+                          Qt::AlignRight | Qt::AlignVCenter);
+  m_mainLayout->addWidget(field, currentRow, 1);
+
+  connect(field, SIGNAL(currentParamChanged()), m_paramViewer,
+          SIGNAL(currentFxParamChanged()));
+  connect(field, SIGNAL(actualParamChanged()), m_paramViewer,
+          SIGNAL(actualFxParamChanged()));
+  connect(field, SIGNAL(paramKeyToggle()), m_paramViewer,
+          SIGNAL(paramKeyChanged()));
+}
+
 //-----------------------------------------------------------------------------
 
 void ParamsPage::setPageSpace() {
   if (m_fields.count() != 0) {
-    QWidget *spaceWidget = new QWidget();
-
     int currentRow = m_mainLayout->rowCount();
-    m_mainLayout->addWidget(spaceWidget, currentRow, 0, 1, 2);
-
     for (int i = 0; i < currentRow; i++) m_mainLayout->setRowStretch(i, 0);
     m_mainLayout->setRowStretch(currentRow, 1);
   }
@@ -593,7 +628,7 @@ QSize getItemSize(QLayoutItem *item) {
   }
 
   ParamField *pF = dynamic_cast<ParamField *>(item->widget());
-  if (pF) return pF->getPreferedSize();
+  if (pF) return pF->getPreferredSize();
 
   Separator *sep = dynamic_cast<Separator *>(item->widget());
   if (sep) return QSize(0, 16);
@@ -636,29 +671,26 @@ void updateMaximumPageSize(QGridLayout *layout, int &maxLabelWidth,
     }
   }
 
+  int itemCount = 0;
   /*-- Widget側の最適な縦サイズおよび横幅の最大値を得る --*/
-  QMap<int, int> heightsByMode;
-  int maxModeHeight = 0;
   for (int r = 0; r < layout->rowCount(); r++) {
     /*-- Column1にある可能性のあるもの：ParamField, Histogram, Layout,
      * RgbLinkButtons --*/
 
     QLayoutItem *item = layout->itemAtPosition(r, 1);
-    if (!item) continue;
+    if (!item || (item->widget() && item->widget()->isHidden())) continue;
 
     ModeSensitiveBox *box = dynamic_cast<ModeSensitiveBox *>(item->widget());
     if (box) {
+      if (!box->isActive()) continue;
       // if (box->isHidden()) continue;
       QGridLayout *innerLay = dynamic_cast<QGridLayout *>(box->layout());
       if (!innerLay) continue;
       int tmpHeight = 0;
       updateMaximumPageSize(innerLay, maxLabelWidth, maxWidgetWidth, tmpHeight);
-      for (int mode : box->modes()) {
-        heightsByMode[mode] += tmpHeight;
-        maxModeHeight = std::max(maxModeHeight, heightsByMode[mode]);
-      }
 
-      // attempt to align the label column
+      fieldsHeight += tmpHeight;
+
       innerLay->setColumnMinimumWidth(0, maxLabelWidth);
       continue;
     }
@@ -666,10 +698,10 @@ void updateMaximumPageSize(QGridLayout *layout, int &maxLabelWidth,
     QSize itemSize = getItemSize(item);
     if (maxWidgetWidth < itemSize.width()) maxWidgetWidth = itemSize.width();
     fieldsHeight += itemSize.height();
+    itemCount++;
   }
-  if (maxModeHeight > 0) fieldsHeight += maxModeHeight;
 
-  if (layout->rowCount() > 1) fieldsHeight += (layout->rowCount() - 1) * 10;
+  if (itemCount >= 1) fieldsHeight += itemCount * 10;
 }
 };  // namespace
 
@@ -919,11 +951,18 @@ void ParamsPageSet::createPage(TIStream &is, const TFxP &fx, int index) {
   std::string tagName;
   if (!is.matchTag(tagName) || tagName != "page")
     throw TException("expected <page>");
-  std::string pageName         = is.getTagAttribute("name");
+  std::string pageName = is.getTagAttribute("name");
   if (pageName == "") pageName = "page";
 
   ParamsPage *paramsPage = new ParamsPage(this, m_parent);
-  paramsPage->setPage(is, fx);
+
+  bool isFirstPageOfFx;
+  if (index < 0)
+    isFirstPageOfFx = (m_pagesList->count() == 0);
+  else  // macro fx case
+    isFirstPageOfFx = !(m_pageFxIndexTable.values().contains(index));
+
+  paramsPage->setPage(is, fx, isFirstPageOfFx);
 
   connect(paramsPage, SIGNAL(preferredPageSizeChanged()), this,
           SLOT(recomputePreferredSize()));
@@ -1197,7 +1236,7 @@ FxSettings::FxSettings(QWidget *parent, const TPixel32 &checkCol1,
   bool ret = true;
   ret      = ret && connect(m_paramViewer, SIGNAL(currentFxParamChanged()),
                        SLOT(updateViewer()));
-  ret = ret &&
+  ret      = ret &&
         connect(m_viewer, SIGNAL(pointPositionChanged(int, const TPointD &)),
                 SLOT(onPointChanged(int, const TPointD &)));
   ret = ret && connect(m_paramViewer, SIGNAL(preferredSizeChanged(QSize)), this,
@@ -1345,10 +1384,10 @@ void FxSettings::setFx(const TFxP &currentFx, const TFxP &actualFx) {
     TFxUtil::setKeyframe(currentFxWithoutCamera, m_frameHandle->getFrameIndex(),
                          actualFx, m_frameHandle->getFrameIndex());
 
-  ToonzScene *scene        = 0;
+  ToonzScene *scene = 0;
   if (m_sceneHandle) scene = m_sceneHandle->getScene();
 
-  int frameIndex                = 0;
+  int frameIndex = 0;
   if (m_frameHandle) frameIndex = m_frameHandle->getFrameIndex();
 
   m_paramViewer->setFx(currentFxWithoutCamera, actualFx, frameIndex, scene);
@@ -1408,7 +1447,7 @@ void FxSettings::setCurrentFx() {
   if (TZeraryColumnFx *zfx = dynamic_cast<TZeraryColumnFx *>(fx.getPointer()))
     fx = zfx->getZeraryFx();
   else
-    hasEmptyInput   = hasEmptyInputPort(fx);
+    hasEmptyInput = hasEmptyInputPort(fx);
   int frame         = m_frameHandle->getFrame();
   ToonzScene *scene = m_sceneHandle->getScene();
   actualFx          = fx;
@@ -1585,10 +1624,17 @@ void FxSettings::onViewModeChanged(QAction *triggeredAct) {
 //-----------------------------------------------------------------------------
 
 void FxSettings::onPreferredSizeChanged(QSize pvBestSize) {
+  DockWidget *popup = dynamic_cast<DockWidget *>(parentWidget());
+  if (!popup || !popup->isFloating()) return;
+
   QSize popupBestSize = pvBestSize;
 
+  static int maximumHeight =
+      (QGuiApplication::primaryScreen()->geometry().height()) * 0.9;
+
   // Set minimum size, just in case
-  popupBestSize.setHeight(std::max(popupBestSize.height(), 85));
+  popupBestSize.setHeight(
+      std::min(std::max(popupBestSize.height(), 85), maximumHeight));
   popupBestSize.setWidth(std::max(popupBestSize.width(), 390));
 
   if (m_toolBar->isVisible()) {
@@ -1597,13 +1643,10 @@ void FxSettings::onPreferredSizeChanged(QSize pvBestSize) {
         std::max(popupBestSize.width(), m_viewer->width() + 13));
   }
 
-  DockWidget *popup = dynamic_cast<DockWidget *>(parentWidget());
-  if (popup && popup->isFloating()) {
-    QRect geom = popup->geometry();
-    geom.setSize(popupBestSize);
-    popup->setGeometry(geom);
-    popup->update();
-  }
+  QRect geom = popup->geometry();
+  geom.setSize(popupBestSize);
+  popup->setGeometry(geom);
+  popup->update();
 }
 
 //-----------------------------------------------------------------------------
