@@ -31,9 +31,38 @@
 #include <QFileInfo>
 #include <QDesktopWidget>
 #include <QSvgRenderer>
+#include <QScreen>
+#include <QWindow>
 
 using namespace DVGui;
 
+namespace {
+inline bool hasScreensWithDifferentDevPixRatio() {
+  static bool ret     = false;
+  static bool checked = false;
+  if (!checked) {  // check once
+    int dpr = QApplication::desktop()->devicePixelRatio();
+    for (auto screen : QGuiApplication::screens()) {
+      if ((int)screen->devicePixelRatio() != dpr) {
+        ret = true;
+        break;
+      }
+    }
+    checked = true;
+  }
+  return ret;
+}
+
+int getHighestDevicePixelRatio() {
+  static int highestDevPixRatio = 0;
+  if (highestDevPixRatio == 0) {
+    for (auto screen : QGuiApplication::screens())
+      highestDevPixRatio =
+          std::max(highestDevPixRatio, (int)screen->devicePixelRatio());
+  }
+  return highestDevPixRatio;
+}
+}  // namespace
 //-----------------------------------------------------------------------------
 
 QString fileSizeString(qint64 size, int precision) {
@@ -78,7 +107,7 @@ QPixmap rasterToQPixmap(const TRaster32P &ras, bool premultiplied,
                         bool setDevPixRatio) {
   QPixmap pixmap = QPixmap::fromImage(rasterToQImage(ras, premultiplied));
   if (setDevPixRatio) {
-    pixmap.setDevicePixelRatio(getDevPixRatio());
+    pixmap.setDevicePixelRatio(getDevicePixelRatio());
   }
   return pixmap;
 }
@@ -158,7 +187,7 @@ QPixmap scalePixmapKeepingAspectRatio(QPixmap pixmap, QSize size,
 
 QPixmap svgToPixmap(const QString &svgFilePath, const QSize &size,
                     Qt::AspectRatioMode aspectRatioMode, QColor bgColor) {
-  static int devPixRatio = getDevPixRatio();
+  static int devPixRatio = getHighestDevicePixelRatio();
   QSvgRenderer svgRenderer(svgFilePath);
   QSize pixmapSize;
   QRectF renderRect;
@@ -197,7 +226,16 @@ QPixmap svgToPixmap(const QString &svgFilePath, const QSize &size,
 
 //-----------------------------------------------------------------------------
 
-int getDevPixRatio() {
+int getDevicePixelRatio(const QWidget *widget) {
+  if (hasScreensWithDifferentDevPixRatio() && widget) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+    return widget->screen()->devicePixelRatio();
+#else
+    if (!widget->windowHandle()) widget->winId();
+    if (widget->windowHandle())
+      return widget->windowHandle()->devicePixelRatio();
+#endif
+  }
   static int devPixRatio = QApplication::desktop()->devicePixelRatio();
   return devPixRatio;
 }
@@ -224,7 +262,7 @@ QString getIconThemePath(const QString &fileSVGPath) {
 
 QPixmap compositePixmap(QPixmap pixmap, const qreal &opacity, const QSize &size,
                         const int leftAdj, const int topAdj, QColor bgColor) {
-  static int devPixRatio = getDevPixRatio();
+  static int devPixRatio = getHighestDevicePixelRatio();
 
   // Sets size of destination pixmap for source to be drawn onto, if size is
   // empty use source pixmap size, else use custom size.
@@ -269,7 +307,7 @@ QPixmap recolorPixmap(QPixmap pixmap, QColor color) {
 
 QIcon createQIcon(const char *iconSVGName, bool useFullOpacity,
                   bool isForMenuItem) {
-  static int devPixRatio = getDevPixRatio();
+  static int devPixRatio = getHighestDevicePixelRatio();
 
   QIcon themeIcon = QIcon::fromTheme(iconSVGName);
 
@@ -285,7 +323,7 @@ QIcon createQIcon(const char *iconSVGName, bool useFullOpacity,
   const qreal baseOpacity     = useFullOpacity ? 1 : 0.8;
   const qreal disabledOpacity = 0.15;
 
-  // Psuedo state name strings
+  // Pseudo state name strings
   QString overStr = QString(iconSVGName) + "_over";
   QString onStr   = QString(iconSVGName) + "_on";
 
