@@ -846,6 +846,16 @@ void MeasuredDoubleParamField::onChange(bool dragging) {
 
 void MeasuredDoubleParamField::onKeyToggled() { onKeyToggle(); }
 
+//-----------------------------------------------------------------------------
+
+void MeasuredDoubleParamField::setPrecision(int precision) {
+  double min, max;
+  m_measuredDoubleField->getRange(min, max);
+  m_measuredDoubleField->setDecimals(precision);
+  // update slider
+  m_measuredDoubleField->setRange(min, max);
+}
+
 //=============================================================================
 // MeasuredRangeParamField
 //-----------------------------------------------------------------------------
@@ -1293,14 +1303,30 @@ ModeSensitiveBox::ModeSensitiveBox(QWidget *parent,
                                    ModeChangerParamField *modeChanger,
                                    QList<int> modes)
     : QWidget(parent), m_modes(modes) {
+  m_currentMode = m_modes.first();
   connect(modeChanger, SIGNAL(modeChanged(int)), this,
           SLOT(onModeChanged(int)));
 }
 
+ModeSensitiveBox::ModeSensitiveBox(QWidget *parent, QCheckBox *checkBox)
+    : QWidget(parent) {
+  m_modes << 1;
+  connect(
+      checkBox, &QCheckBox::stateChanged, this,
+      [=]() { onModeChanged(checkBox->isChecked() ? 1 : 0); },
+      Qt::AutoConnection);
+}
+
 //-----------------------------------------------------------------------------
 
 void ModeSensitiveBox::onModeChanged(int modeValue) {
-  setVisible(m_modes.contains(modeValue));
+  bool wasVisible = isVisible();
+  m_currentMode   = modeValue;
+  if (wasVisible == m_modes.contains(modeValue)) return;
+  setVisible(!wasVisible);
+
+  ParamsPage *paramsPage = dynamic_cast<ParamsPage *>(parentWidget());
+  if (paramsPage) emit paramsPage->preferredPageSizeChanged();
 }
 
 //=============================================================================
@@ -1836,7 +1862,7 @@ void ToneCurveParamField::setParams() {
 
 //-----------------------------------------------------------------------------
 
-QSize ToneCurveParamField::getPreferedSize() {
+QSize ToneCurveParamField::getPreferredSize() {
   if (m_toneCurveField->isEnlarged())
     return QSize(676, 640);
   else
