@@ -15,10 +15,17 @@
 #include <QMenuBar>
 #include <QPolygonF>
 #include <QDesktopWidget>
+#include <QClipboard>
 #include "tundo.h"
 #include "toonzqt/menubarcommand.h"
 #include "toonzqt/gutil.h"
 
+#define ACCEL_KEY(k)                                                           \
+  (!QCoreApplication::testAttribute(Qt::AA_DontShowShortcutsInContextMenus)    \
+       ? QLatin1Char('\t') +                                                   \
+             QKeySequence(k).toString(QKeySequence::NativeText)                \
+       : QString())
+
 //========================================================
 //
 // StageSchematicName
@@ -26,22 +33,65 @@
 //========================================================
 
 SchematicName::SchematicName(QGraphicsItem *parent, double width, double height)
-    : QGraphicsTextItem("", parent), m_width(width), m_height(height) {
+    : QGraphicsTextItem("", parent)
+    , m_width(width)
+    , m_height(height)
+    , m_defName("")
+    , m_curName("")
+    , m_refocus(false) {
   setFlag(QGraphicsItem::ItemIsSelectable, true);
   setFlag(QGraphicsItem::ItemIsFocusable, true);
   setTextInteractionFlags(Qt::TextEditorInteraction);
 
+  popup = new QMenu();
+  popup->setObjectName(QLatin1String("qt_edit_menu"));
+
+  actionCut = popup->addAction(tr("Cu&t") + ACCEL_KEY(QKeySequence::Cut), this,
+                               SLOT(onCut()));
+  actionCut->setObjectName(QStringLiteral("edit-cut"));
+
+  actionCopy = popup->addAction(tr("&Copy") + ACCEL_KEY(QKeySequence::Copy),
+                                this, SLOT(onCopy()));
+  actionCopy->setObjectName(QStringLiteral("edit-copy"));
+
+  actionPaste = popup->addAction(tr("&Paste") + ACCEL_KEY(QKeySequence::Paste),
+                                 this, SLOT(onPaste()));
+  actionPaste->setObjectName(QStringLiteral("edit-paste"));
+
+  actionDelete = popup->addAction(
+      tr("&Delete") + ACCEL_KEY(QKeySequence::Delete), this, SLOT(onDelete()));
+  actionDelete->setObjectName(QStringLiteral("edit-delete"));
+
+  popup->addSeparator();
+
+  actionSelectAll =
+      popup->addAction(tr("Select &All") + ACCEL_KEY(QKeySequence::SelectAll),
+                       this, SLOT(onSelectAll()));
+  actionSelectAll->setObjectName(QStringLiteral("select-all"));
+
   connect(document(), SIGNAL(contentsChanged()), this,
           SLOT(onContentsChanged()));
+  connect(popup, SIGNAL(aboutToHide()), this, SLOT(onPopupHide()));
 }
 
 //--------------------------------------------------------
 
-SchematicName::~SchematicName() {}
+SchematicName::~SchematicName() { delete popup; }
 
 //--------------------------------------------------------
 
-void SchematicName::setName(const QString &name) { setPlainText(name); }
+void SchematicName::setName(const QString &name) {
+  m_defName = name;
+  setPlainText(name);
+}
+
+//--------------------------------------------------------
+
+void SchematicName::acceptName(const QString &name) {
+  m_curName = name;
+  m_curName.remove(QRegExp("[\\n\\r]"));  // remove all newlines
+  setPlainText(m_curName);
+}
 
 //--------------------------------------------------------
 
@@ -51,7 +101,8 @@ void SchematicName::onContentsChanged() {
   int position       = cursor.position();
   if (position > 0 && text.at(position - 1) == '\n') {
     text.remove("\n");
-    setPlainText(text);
+    if (text.isEmpty()) text = m_defName;
+    acceptName(text);
     ;
     emit focusOut();
   }
@@ -61,7 +112,10 @@ void SchematicName::onContentsChanged() {
 
 void SchematicName::focusOutEvent(QFocusEvent *fe) {
   qApp->removeEventFilter(this);
-  if (fe->reason() == Qt::MouseFocusReason) emit focusOut();
+  if (fe->reason() == Qt::MouseFocusReason) {
+    acceptName(toPlainText());
+    emit focusOut();
+  }
 }
 
 //--------------------------------------------------------
@@ -75,6 +129,9 @@ void SchematicName::keyPressEvent(QKeyEvent *ke) {
     else
       cursor.setPosition(currentPos + 1);
     setTextCursor(cursor);
+  } else if (ke->key() == Qt::Key_Escape) {
+    setPlainText(m_curName);
+    emit focusOut();
   } else
     QGraphicsTextItem::keyPressEvent(ke);
 }
@@ -97,6 +154,116 @@ bool SchematicName::eventFilter(QObject *object, QEvent *event) {
 void SchematicName::focusInEvent(QFocusEvent *fe) {
   QGraphicsTextItem::focusInEvent(fe);
   qApp->installEventFilter(this);
+  if (!m_refocus) {
+    QTextDocument *doc = document();
+    QTextCursor cursor(doc->begin());
+    cursor.select(QTextCursor::Document);
+    setTextCursor(cursor);
+    m_curName = toPlainText();
+  }
+}
+
+//--------------------------------------------------------
+
+void SchematicName::contextMenuEvent(QGraphicsSceneContextMenuEvent *cme) {
+  QClipboard *clipboard = QApplication::clipboard();
+  QTextCursor cursor    = textCursor();
+
+  actionCut->setEnabled(cursor.hasSelection());
+  actionCopy->setEnabled(cursor.hasSelection());
+  actionPaste->setEnabled(!clipboard->text().isEmpty());
+  actionDelete->setEnabled(cursor.hasSelection());
+  actionSelectAll->setEnabled(cursor.selectedText() != toPlainText());
+
+  popup->popup(cme->screenPos());
+}
+
+//--------------------------------------------------------
+
+void SchematicName::onPopupHide() {
+  m_refocus = true;
+  setFocus();
+  m_refocus = false;
+}
+
+//--------------------------------------------------------
+
+void SchematicName::onCut() {
+  QClipboard *clipboard = QApplication::clipboard();
+  QTextCursor cursor    = textCursor();
+  QString plainText     = toPlainText();
+
+  if (cursor.hasSelection()) {
+    int p             = cursor.selectionStart();
+    int n             = cursor.selectionEnd() - p;
+    QString selection = plainText.mid(p, n);
+    clipboard->setText(selection);
+    plainText.remove(p, n);
+    acceptName(plainText);
+    cursor.setPosition(p);
+    setTextCursor(cursor);
+  }
+}
+
+//--------------------------------------------------------
+
+void SchematicName::onCopy() {
+  QClipboard *clipboard = QApplication::clipboard();
+  QTextCursor cursor    = textCursor();
+  QString plainText     = toPlainText();
+
+  if (cursor.hasSelection()) {
+    int p = cursor.selectionStart();
+    int n = cursor.selectionEnd() - p;
+    clipboard->setText(plainText.mid(p, n));
+  } else {
+    clipboard->setText(plainText);
+  }
+}
+
+//--------------------------------------------------------
+
+void SchematicName::onPaste() {
+  QClipboard *clipboard = QApplication::clipboard();
+  QTextCursor cursor    = textCursor();
+  QString plainText     = toPlainText();
+  QString clipboardText = clipboard->text();
+  clipboardText.remove(QRegExp("[\\n\\r]"));  // remove all newlines
+
+  int n, p = cursor.position();
+  if (cursor.hasSelection()) {
+    p = cursor.selectionStart();
+    n = cursor.selectionEnd() - p;
+    plainText.remove(p, n);
+    plainText.insert(p, clipboardText);
+  } else {
+    plainText.insert(p, clipboardText);
+  }
+  acceptName(plainText);
+  cursor.setPosition(p + clipboardText.length());
+  setTextCursor(cursor);
+}
+
+//--------------------------------------------------------
+
+void SchematicName::onDelete() {
+  QClipboard *clipboard = QApplication::clipboard();
+  QTextCursor cursor    = textCursor();
+  QString plainText     = toPlainText();
+
+  if (cursor.hasSelection()) {
+    int p = cursor.selectionStart();
+    int n = cursor.selectionEnd() - p;
+    plainText.remove(p, n);
+    acceptName(plainText);
+    cursor.setPosition(p);
+    setTextCursor(cursor);
+  }
+}
+
+//--------------------------------------------------------
+
+void SchematicName::onSelectAll() {
   QTextDocument *doc = document();
   QTextCursor cursor(doc->begin());
   cursor.select(QTextCursor::Document);
@@ -136,10 +303,8 @@ void SchematicThumbnailToggle::paint(QPainter *painter,
   if (m_isDown)
     pixmap = offIcon.pixmap(sourceRect.size());
   else
-    pixmap   = onIcon.pixmap(sourceRect.size());
-  sourceRect = QRect(0, 0, sourceRect.width() * getDevPixRatio(),
-                     sourceRect.height() * getDevPixRatio());
-  painter->drawPixmap(rect, pixmap, sourceRect);
+    pixmap = onIcon.pixmap(sourceRect.size());
+  painter->drawPixmap(rect, pixmap);
 }
 
 //--------------------------------------------------------
@@ -257,9 +422,7 @@ void SchematicToggle::paint(QPainter *painter,
     QRect sourceRect =
         scene()->views()[0]->matrix().mapRect(QRect(0, 0, 18, 17));
     QPixmap redPm = pix.pixmap(sourceRect.size());
-    QRect newRect = QRect(0, 0, sourceRect.width() * getDevPixRatio(),
-                          sourceRect.height() * getDevPixRatio());
-    painter->drawPixmap(rect, redPm, newRect);
+    painter->drawPixmap(rect, redPm);
   } else if (!m_imageOff.isNull()) {
     QPen pen(m_colorOn);
     pen.setWidthF(0.5);
@@ -270,9 +433,7 @@ void SchematicToggle::paint(QPainter *painter,
     QRect sourceRect =
         scene()->views()[0]->matrix().mapRect(QRect(0, 0, 18, 17));
     QPixmap redPm = m_imageOff.pixmap(sourceRect.size());
-    QRect newRect = QRect(0, 0, sourceRect.width() * getDevPixRatio(),
-                          sourceRect.height() * getDevPixRatio());
-    painter->drawPixmap(rect, redPm, newRect);
+    painter->drawPixmap(rect, redPm);
   }
 }
 
@@ -326,7 +487,7 @@ void SchematicToggle::contextMenuEvent(QGraphicsSceneContextMenuEvent *cme) {
 
 //--------------------------------------------------------
 /*! for Spline Aim and CP toggles
-*/
+ */
 void SchematicToggle_SplineOptions::paint(
     QPainter *painter, const QStyleOptionGraphicsItem *option,
     QWidget *widget) {
@@ -337,9 +498,7 @@ void SchematicToggle_SplineOptions::paint(
         (m_state == 2 && !m_imageOn2.isNull()) ? m_imageOn2 : m_imageOn;
     QRect sourceRect = scene()->views()[0]->matrix().mapRect(rect.toRect());
     QPixmap redPm    = pix.pixmap(sourceRect.size());
-    QRect newRect    = QRect(0, 0, sourceRect.width() * getDevPixRatio(),
-                          sourceRect.height() * getDevPixRatio());
-    painter->drawPixmap(rect, redPm, newRect);
+    painter->drawPixmap(rect.toRect(), redPm);
   }
   painter->setBrush(Qt::NoBrush);
   painter->setPen(QColor(180, 180, 180, 255));
@@ -348,7 +507,7 @@ void SchematicToggle_SplineOptions::paint(
 
 //--------------------------------------------------------
 /*! for Spline Aim and CP toggles
-*/
+ */
 void SchematicToggle_SplineOptions::mousePressEvent(
     QGraphicsSceneMouseEvent *me) {
   SchematicToggle::mousePressEvent(me);
@@ -394,8 +553,8 @@ void SchematicHandleSpinBox::paint(QPainter *painter,
 
 void SchematicHandleSpinBox::mouseMoveEvent(QGraphicsSceneMouseEvent *me) {
   if (m_buttonState == Qt::LeftButton) {
-    bool increase           = false;
-    int delta               = me->screenPos().y() - me->lastScreenPos().y();
+    bool increase = false;
+    int delta     = me->screenPos().y() - me->lastScreenPos().y();
     if (delta < 0) increase = true;
     m_delta += abs(delta);
     if (m_delta > 5) {
@@ -677,6 +836,7 @@ void SchematicPort::mouseMoveEvent(QGraphicsSceneMouseEvent *me) {
 
   // Snapping
   SchematicPort *linkingTo = searchPort(me->scenePos());
+
   if (!linkingTo) {
     for (SchematicLink *ghostLink : m_ghostLinks) {
       ghostLink->updateEndPos(me->scenePos());
@@ -688,8 +848,12 @@ void SchematicPort::mouseMoveEvent(QGraphicsSceneMouseEvent *me) {
       m_linkingTo = nullptr;
     }
   }
-  // if to be connected something
-  else if (linkingTo != this) {
+  // if to be connected something new
+  else if (linkingTo != this && m_linkingTo != linkingTo) {
+    if (m_linkingTo) {
+      m_linkingTo->highLight(false);
+      m_linkingTo->update();
+    }
     m_linkingTo = linkingTo;
     for (SchematicLink *ghostLink : m_ghostLinks) {
       ghostLink->updatePath(ghostLink->getStartPort(), linkingTo);
@@ -873,7 +1037,7 @@ QPointF SchematicPort::getLinkEndPoint() const { return scenePos() + m_hook; }
 //
 //========================================================
 
-/*! \class SchematicNode schematicnode.h "../inlcude/toonzqt/schematicnode.h"
+/*! \class SchematicNode schematicnode.h "../include/toonzqt/schematicnode.h"
         \brief The class provides methods to draw and handle a node item in the
    SchematicScene.
 */
@@ -916,13 +1080,13 @@ SchematicNode::~SchematicNode() {}
 //--------------------------------------------------------
 
 /*!Reimplements the pure virtual QGraphicsItem::boundingRect() method.
-*/
+ */
 QRectF SchematicNode::boundingRect() const { return QRectF(0, 0, 1, 1); }
 
 //--------------------------------------------------------
 
 /*! Reimplements the pure virtual QGraphicsItem::paint() method.
-*/
+ */
 void SchematicNode::paint(QPainter *painter,
                           const QStyleOptionGraphicsItem *option,
                           QWidget *widget) {
@@ -956,7 +1120,7 @@ void SchematicNode::paint(QPainter *painter,
 //--------------------------------------------------------
 
 /*! Reimplements the QGraphicsItem::mouseMoveEvent() method.
-*/
+ */
 void SchematicNode::mouseMoveEvent(QGraphicsSceneMouseEvent *me) {
   QList<QGraphicsItem *> items = scene()->selectedItems();
   if (items.empty()) return;
@@ -999,7 +1163,7 @@ void SchematicNode::mouseReleaseEvent(QGraphicsSceneMouseEvent *me) {
 
 //--------------------------------------------------------
 /* Add a pair (portId, SchematicPort*port) in the mapping
-*/
+ */
 SchematicPort *SchematicNode::addPort(int portId, SchematicPort *port) {
   QMap<int, SchematicPort *>::iterator it;
   it = m_ports.find(portId);
@@ -1039,7 +1203,7 @@ SchematicPort *SchematicNode::getPort(int portId) const {
 
 /*! Returns a list of all node connected by links to a SchematicPort identified
  * by \b portId.
-*/
+ */
 QList<SchematicNode *> SchematicNode::getLinkedNodes(int portId) const {
   QList<SchematicNode *> list;
   SchematicPort *port = getPort(portId);
