@@ -763,9 +763,7 @@ void StageSchematicNodePort::paint(QPainter *painter,
       else
         pixmap = QIcon(":Resources/port_red.svg").pixmap(sourceRect.size());
     }
-    sourceRect = QRect(0, 0, sourceRect.width() * getDevPixRatio(),
-                       sourceRect.height() * getDevPixRatio());
-    painter->drawPixmap(imgRect, pixmap, sourceRect);
+    painter->drawPixmap(imgRect, pixmap);
   }
 }
 
@@ -904,8 +902,8 @@ QRectF StageSchematicSplinePort::boundingRect() const {
 void StageSchematicSplinePort::paint(QPainter *painter,
                                      const QStyleOptionGraphicsItem *option,
                                      QWidget *widget) {
-  QRect rect(0, 0, 16, 8);
-  QRect sourceRect = scene()->views()[0]->matrix().mapRect(rect);
+  QRect sourceRect =
+      scene()->views()[0]->matrix().mapRect(boundingRect().toRect());
   QPixmap pixmap;
 
   if (!m_parent->isParentPort()) {
@@ -921,9 +919,7 @@ void StageSchematicSplinePort::paint(QPainter *painter,
     static QIcon splineParentIcon(":Resources/spline_parent_port.svg");
     pixmap = splineParentIcon.pixmap(sourceRect.size());
   }
-  sourceRect = QRect(0, 0, sourceRect.width() * getDevPixRatio(),
-                     sourceRect.height() * getDevPixRatio());
-  painter->drawPixmap(rect, pixmap, sourceRect);
+  painter->drawPixmap(boundingRect().toRect(), pixmap);
 }
 
 //--------------------------------------------------------
@@ -1014,8 +1010,8 @@ SplineAimChanger::~SplineAimChanger() {}
 
 void SplineAimChanger::mouseMoveEvent(QGraphicsSceneMouseEvent *me) {
   if (m_buttonState == Qt::LeftButton) {
-    bool increase           = false;
-    int delta               = me->screenPos().y() - me->lastScreenPos().y();
+    bool increase = false;
+    int delta     = me->screenPos().y() - me->lastScreenPos().y();
     if (delta < 0) increase = true;
     m_delta += abs(delta);
     if (m_delta > 15) {
@@ -1560,10 +1556,12 @@ void StageSchematicNode::onHandleReleased() {
 StageSchematicPegbarNode::StageSchematicPegbarNode(StageSchematicScene *scene,
                                                    TStageObject *pegbar)
     : StageSchematicNode(scene, pegbar, 90, 18) {
-  std::string name = m_stageObject->getFullName();
-  std::string id   = m_stageObject->getId().toString();
-  m_name           = QString::fromStdString(name);
-  m_nameItem       = new SchematicName(this, 72, 20);
+  SchematicViewer *viewer = scene->getSchematicViewer();
+  std::string name        = m_stageObject->getFullName();
+  std::string id          = m_stageObject->getId().toString();
+  m_name                  = QString::fromStdString(name);
+  m_nameItem              = new SchematicName(this, 72, 20);
+  m_nameItem->setDefaultTextColor(viewer->getTextColor());
   m_nameItem->setName(m_name);
   m_nameItem->setPos(16, -1);
   m_nameItem->setZValue(2);
@@ -1705,6 +1703,7 @@ StageSchematicColumnNode::StageSchematicColumnNode(StageSchematicScene *scene,
                        SLOT(onChangedSize(bool)));
 
   m_nameItem = new SchematicName(this, 54, 20);
+  m_nameItem->setDefaultTextColor(viewer->getTextColor());
   m_nameItem->setName(m_name);
   m_nameItem->setPos(16, -1);
   m_nameItem->setZValue(2);
@@ -2004,10 +2003,12 @@ void StageSchematicColumnNode::onCameraStandToggleClicked(int state) {
 StageSchematicCameraNode::StageSchematicCameraNode(StageSchematicScene *scene,
                                                    TStageObject *pegbar)
     : StageSchematicNode(scene, pegbar, 90, 18) {
-  std::string name = m_stageObject->getFullName();
-  m_name           = QString::fromStdString(name);
+  SchematicViewer *viewer = scene->getSchematicViewer();
+  std::string name        = m_stageObject->getFullName();
+  m_name                  = QString::fromStdString(name);
 
   m_nameItem = new SchematicName(this, 54, 20);
+  m_nameItem->setDefaultTextColor(viewer->getTextColor());
   m_nameItem->setName(m_name);
 
   m_nameItem->setPos(16, -2);
@@ -2083,8 +2084,9 @@ void StageSchematicCameraNode::onNameChanged() {
 StageSchematicSplineNode::StageSchematicSplineNode(StageSchematicScene *scene,
                                                    TStageObjectSpline *spline)
     : SchematicNode(scene), m_spline(spline), m_isOpened(false) {
-  m_width  = 90;
-  m_height = 18;
+  SchematicViewer *viewer = scene->getSchematicViewer();
+  m_width                 = 90;
+  m_height                = 18;
   assert(spline);
 
   m_dock = new StageSchematicSplineDock(this, true, eStageSplinePort);
@@ -2100,6 +2102,7 @@ StageSchematicSplineNode::StageSchematicSplineNode(StageSchematicScene *scene,
   std::string name = m_spline->getName();
   m_splineName     = QString::fromStdString(name);
   m_nameItem       = new SchematicName(this, 72, 20);
+  m_nameItem->setDefaultTextColor(viewer->getTextColor());
   m_nameItem->setName(m_splineName);
   m_nameItem->setPos(16, -1);
   m_nameItem->setZValue(2);
@@ -2155,7 +2158,6 @@ void StageSchematicSplineNode::setSchematicNodePos(const QPointF &pos) const {
 
 QPixmap StageSchematicSplineNode::getPixmap() {
   return IconGenerator::instance()->getIcon(m_spline);
-  return QPixmap();
 }
 
 //--------------------------------------------------------
@@ -2213,13 +2215,15 @@ StageSchematicGroupNode::StageSchematicGroupNode(
     : StageSchematicNode(scene, root, 90, 18, true)
     , m_root(root)
     , m_groupedObj(groupedObj) {
+  SchematicViewer *viewer = scene->getSchematicViewer();
   int i;
-  for (i   = 0; i < m_groupedObj.size(); i++) m_groupedObj[i]->addRef();
-  bool ret = true;
+  for (i = 0; i < m_groupedObj.size(); i++) m_groupedObj[i]->addRef();
+  bool ret          = true;
   std::wstring name = m_stageObject->getGroupName(false);
   m_name            = QString::fromStdWString(name);
 
   m_nameItem = new SchematicName(this, 72, 20);
+  m_nameItem->setDefaultTextColor(viewer->getTextColor());
   m_nameItem->setName(m_name);
   m_nameItem->setPos(16, -1);
   m_nameItem->setZValue(2);
