@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="zh_CN" sourcelanguage="en">
+<TS version="2.1" language="zh_CN" sourcelanguage="en_US">
 <context>
     <name>CenterlineVectorizer</name>
     <message>
@@ -576,7 +576,7 @@
     </message>
     <message>
         <source>Toggle Autopaint Option  Palette : %1  Style#%2</source>
-        <translation>开关自动填充选项  调色板: %1  样式#%2</translation>
+        <translation>启用/停止自动填充选项  调色板: %1  样式#%2</translation>
     </message>
     <message>
         <source>Can&apos;t undo rename palette</source>
@@ -620,6 +620,42 @@
         <source>and %1 more item(s).</source>
         <translation>和 %1 更多项目。</translation>
     </message>
+    <message>
+        <source>Orange</source>
+        <translation>橙色</translation>
+    </message>
+    <message>
+        <source>Yellow</source>
+        <translation>黄色</translation>
+    </message>
+    <message>
+        <source>Light Green</source>
+        <translation>浅绿色</translation>
+    </message>
+    <message>
+        <source>Light Blue</source>
+        <translation>浅蓝色</translation>
+    </message>
+    <message>
+        <source>Dark Blue</source>
+        <translation>深蓝色</translation>
+    </message>
+    <message>
+        <source>Purple</source>
+        <translation>紫色</translation>
+    </message>
+    <message>
+        <source>Pink</source>
+        <translation>粉色</translation>
+    </message>
+    <message>
+        <source>Dark Pink</source>
+        <translation>深粉色</translation>
+    </message>
+    <message>
+        <source>White</source>
+        <translation>白色</translation>
+    </message>
 </context>
 <context>
     <name>Rasterizer</name>
