@@ -739,6 +739,10 @@
         <source>Lines &amp; Areas</source>
         <translation>線と塗り</translation>
     </message>
+    <message>
+        <source>Lock Alpha</source>
+        <translation>透明部分の保護</translation>
+    </message>
 </context>
 <context>
     <name>PinchTool</name>
@@ -1051,6 +1055,10 @@ Do you want to proceed?</source>
         <source>Smooth</source>
         <translation>滑らかに連結</translation>
     </message>
+    <message>
+        <source>Rotate</source>
+        <translation>作成後に回転</translation>
+    </message>
 </context>
 <context>
     <name>PumpTool</name>
@@ -1603,6 +1611,10 @@ moved to the end of the first page of the palette.</source>
         <source>Pressure</source>
         <translation>圧力感知</translation>
     </message>
+    <message>
+        <source>Lock Alpha</source>
+        <translation>透明部分の保護</translation>
+    </message>
 </context>
 <context>
     <name>ToonzVectorBrushTool</name>
