@@ -450,6 +450,42 @@
         <source>and %1 more item(s).</source>
         <translation>さらに %1 個のファイル。</translation>
     </message>
+    <message>
+        <source>Orange</source>
+        <translation>オレンジ</translation>
+    </message>
+    <message>
+        <source>Yellow</source>
+        <translation>黄色</translation>
+    </message>
+    <message>
+        <source>Light Green</source>
+        <translation>黄緑</translation>
+    </message>
+    <message>
+        <source>Light Blue</source>
+        <translation>水色</translation>
+    </message>
+    <message>
+        <source>Dark Blue</source>
+        <translation>暗い青</translation>
+    </message>
+    <message>
+        <source>Purple</source>
+        <translation>紫</translation>
+    </message>
+    <message>
+        <source>Pink</source>
+        <translation>ピンク</translation>
+    </message>
+    <message>
+        <source>Dark Pink</source>
+        <translation>暗いピンク</translation>
+    </message>
+    <message>
+        <source>White</source>
+        <translation>白</translation>
+    </message>
 </context>
 <context>
     <name>TScriptBinding::CenterlineVectorizer</name>
