@@ -675,6 +675,10 @@
         <source>Selective</source>
         <translation>선택</translation>
     </message>
+    <message>
+        <source>Lock Alpha</source>
+        <translation>잠금 알파</translation>
+    </message>
 </context>
 <context>
     <name>PinchTool</name>
@@ -987,6 +991,10 @@ Do you want to proceed?</source>
         <source>Smooth</source>
         <translation>부드러운</translation>
     </message>
+    <message>
+        <source>Rotate</source>
+        <translation>회전</translation>
+    </message>
 </context>
 <context>
     <name>PumpTool</name>
@@ -1537,6 +1545,10 @@ moved to the end of the first page of the palette.</source>
         <source>Pressure</source>
         <translation>압력</translation>
     </message>
+    <message>
+        <source>Lock Alpha</source>
+        <translation>잠금 알파</translation>
+    </message>
 </context>
 <context>
     <name>ToonzVectorBrushTool</name>
