@@ -739,6 +739,10 @@
         <source>Lines &amp; Areas</source>
         <translation>Líneas y áreas</translation>
     </message>
+    <message>
+        <source>Lock Alpha</source>
+        <translation>Preservar alfa</translation>
+    </message>
 </context>
 <context>
     <name>PinchTool</name>
@@ -1051,6 +1055,10 @@ Do you want to proceed?</source>
         <source>Smooth</source>
         <translation>Suavizar</translation>
     </message>
+    <message>
+        <source>Rotate</source>
+        <translation>Rotar</translation>
+    </message>
 </context>
 <context>
     <name>PumpTool</name>
@@ -1300,7 +1308,7 @@ Do you want to proceed?</source>
     <name>RasterSelectionTool</name>
     <message>
         <source>Modify Savebox</source>
-        <translation>Modificar marco delimitador</translation>
+        <translation>Editar marco delimitador</translation>
     </message>
     <message>
         <source>No Antialiasing</source>
@@ -1603,6 +1611,10 @@ movido hacia el final de la primera página de la paleta.</translation>
         <source>Pressure</source>
         <translation>Presión</translation>
     </message>
+    <message>
+        <source>Lock Alpha</source>
+        <translation>Preservar alfa</translation>
+    </message>
 </context>
 <context>
     <name>ToonzVectorBrushTool</name>
