@@ -262,11 +262,11 @@
     </message>
     <message>
         <source>Set Keyframe</source>
-        <translation>Marcar fotograma clave</translation>
+        <translation>Marcar clave</translation>
     </message>
     <message>
         <source>Remove Keyframe</source>
-        <translation>Eliminar fotograma clave</translation>
+        <translation>Eliminar clave</translation>
     </message>
     <message>
         <source>Cycle</source>
@@ -326,11 +326,11 @@
     </message>
     <message>
         <source>Set Keyframe   %1 at frame %2</source>
-        <translation>Marcar fotograma clave   %1 en fotograma %2</translation>
+        <translation>Marcar clave   %1 en fotograma %2</translation>
     </message>
     <message>
         <source>Remove Keyframe   %1 at frame %2</source>
-        <translation>Eliminar fotograma clave   %1 en fotograma %2</translation>
+        <translation>Eliminar clave   %1 en fotograma %2</translation>
     </message>
     <message>
         <source>Move Center   %1  Frame %2</source>
@@ -450,6 +450,42 @@
         <source>and %1 more item(s).</source>
         <translation>y %1 elemento(s) más.</translation>
     </message>
+    <message>
+        <source>Orange</source>
+        <translation>Naranja</translation>
+    </message>
+    <message>
+        <source>Yellow</source>
+        <translation>Amarillo</translation>
+    </message>
+    <message>
+        <source>Light Green</source>
+        <translation>Verde claro</translation>
+    </message>
+    <message>
+        <source>Light Blue</source>
+        <translation>Azul claro</translation>
+    </message>
+    <message>
+        <source>Dark Blue</source>
+        <translation>Azul oscuro</translation>
+    </message>
+    <message>
+        <source>Purple</source>
+        <translation>Morado</translation>
+    </message>
+    <message>
+        <source>Pink</source>
+        <translation>Rosa</translation>
+    </message>
+    <message>
+        <source>Dark Pink</source>
+        <translation>Rosa oscuro</translation>
+    </message>
+    <message>
+        <source>White</source>
+        <translation>Blanco</translation>
+    </message>
 </context>
 <context>
     <name>TScriptBinding::CenterlineVectorizer</name>
